# URL
URL_PS3838 = "https://api.ps3838.com"

# ID for Soccer
ID_SOCCER = 29

# List of sports
DICO_SPORTS = {
    "Badminton" : 1,
    "Bandy" : 2,
    "Baseball" : 3,
    "Basketball" : 4,
    "Beach Volleyball" : 5,
    "Boxing" : 6,
    "Chess" : 7,
    "Cricket" : 8,
    "Curling" : 9,
    "Darts" : 10,
    "Field Hockey" : 13,
    "Floorball" : 14,
    "Football" : 15,
    "Futsal" : 16,
    "Golf" : 17,
    "Handball" : 18,
    "Hockey" : 19,
    "Horse Racing Specials" : 20,
    "Lacrosse" : 21,
    "Mixed Martial Arts" : 22,
    "Other Sports" : 23,
    "Politics" : 24,
    "Rugby League" : 26,
    "Rugby Union" : 27,
    "Snooker" : 28,
    "Soccer" : 29,
    "Softball" : 30,
    "Squash" : 31,
    "Table Tennis" : 32,
    "Tennis" : 33,
    "Volleyball" : 34,
    "Water Polo" : 36,
    "Padel Tennis" : 37,
    "Aussie Rules" : 39,
    "Alpine Skiing" : 40,
    "Biathlon" : 41,
    "Ski Jumping" : 42,
    "Cross Country" : 43,
    "Formula 1" : 44,
    "Cycling" : 45,
    "Bobsleigh" : 46,
    "Figure Skating" : 47,
    "Freestyle Skiing" : 48,
    "Luge" : 49,
    "Nordic Combined" : 50,
    "Short Track" : 51,
    "Skeleton" : 52,
    "Snow Boarding" : 53,
    "Speed Skating" : 54,
    "Olympics" : 55,
    "Athletics" : 56,
    "Crossfit" : 57,
    "Entertainment" : 58,
    "Archery" : 59,
    "Drone Racing" : 60,
    "Poker" : 62,
    "Motorsport" : 63,
    "Simulated Games" : 64,
    "Sumo" : 65
}

# List of leagues
DICO_LEAGUES = {
"Costa Rica" : 
{
	"Costa Rica - U21 League" : 227280,
	"Costa Rica - Cup" : 9532,
	"Costa Rica - U20 League" : 217552,
	"Costa Rica - Super Cup Women" : 223959,
	"Costa Rica - Ascenso" : 210556,
	"Costa Rica - Primera Division Corners" : 72429,
	"Costa Rica - Primera Division Women" : 209654,
	"Costa Rica - Super Cup" : 214750,
	"Costa Rica - Primera Division" : 9531,
},

"Scotland" : 
{
	"Scotland - Premier League Cup Women" : 222842,
	"Scotland - Football League" : 202207,
	"Scotland - League One" : 2418,
	"Scotland - Feeder Leagues" : 219677,
	"Scotland - League One Corners" : 198225,
	"Scotland - League Two Corners" : 210442,
	"Scotland - Cup Women" : 197038,
	"Scotland - Aberdeenshire Shield" : 222745,
	"Scotland - Premier League Women" : 197064,
	"Scotland - SPFL Reserve League" : 202281,
	"Scotland - SPFL Reserve Cup" : 202799,
	"Scotland - League Cup" : 4998,
	"Scotland - Championship Corners" : 6824,
	"Scotland - Regional Cup" : 219182,
	"Scotland - Cup" : 2426,
	"Scotland - Premier League Women 2" : 213792,
	"Scotland - Premier League Women Corners" : 201265,
	"Scotland - SPFL Development League U20" : 10145,
	"Scotland - Premiership" : 2421,
	"Scotland - Cup Corners" : 6315,
	"Scotland - SPFL Development League U20 Corners" : 191925,
	"Scotland - Premiership Corners" : 6519,
	"Scotland - Lowland League Cup" : 218915,
	"Scotland - FA Youth Cup U18" : 207130,
	"Scotland - Championship" : 2417,
	"Scotland - Challenge Cup" : 2420,
	"Scotland - League Two" : 2419,
	"Scotland - League Cup Corners" : 197285,
},

"Algeria" : 
{
	"Algeria - League 2 U21" : 10747,
	"Algeria - League 1 U21" : 218035,
	"Algeria - U19 League" : 218143,
	"Algeria - Cup Women" : 226469,
	"Algeria - Ligue 1 Corners" : 226742,
	"Algeria - Ligue 1 Women" : 217449,
	"Algeria - Ligue 1" : 8667,
	"Algeria - Ligue 2" : 200835,
	"Algeria - U21 Cup" : 224721,
	"Algeria - Cup Corner" : 203070,
	"Algeria - Cup" : 1725,
},

"Brazil" : 
{
	"Brazil - Cearense Women" : 216589,
	"Brazil - Paranaense 3" : 216386,
	"Brazil - Carioca B2" : 216150,
	"Brazil - Copa Espirito Santo" : 219877,
	"Brazil - Cearense U20" : 221837,
	"Brazil - Gaucho U20" : 210905,
	"Brazil - Amazonense Women" : 217483,
	"Brazil - Serie A" : 1834,
	"Brazil - Paranaense 2" : 198925,
	"Brazil - Alagoano U20" : 216918,
	"Brazil - Paulista Women" : 201915,
	"Brazil - Supercopa U20" : 217861,
	"Brazil - Paraibano" : 192778,
	"Brazil - Copa Sul U19" : 206772,
	"Brazil - Catarinense Women" : 216395,
	"Brazil - Copa Santa Catarina" : 202622,
	"Brazil - Maranhense 1" : 192701,
	"Brazil - Maranhense 2" : 221787,
	"Brazil - Paulista Serie B" : 236839,
	"Brazil - Carioca A2" : 215951,
	"Brazil - Paranaense" : 10770,
	"Brazil - Goiano 2" : 206585,
	"Brazil - Copa Alagoas" : 211794,
	"Brazil - Copa FGF" : 206587,
	"Brazil - Paraense" : 198451,
	"Brazil - Paraibano 2" : 216937,
	"Brazil - Cup Bookings" : 227816,
	"Brazil - Pernambucano 3" : 230677,
	"Brazil - Rio Cup Women" : 224496,
	"Brazil - Carioca B1" : 216958,
	"Brazil - Sao Paulo Cup U20" : 218024,
	"Brazil - Paranaense U20" : 219875,
	"Brazil - Gaucho 3" : 213103,
	"Brazil - Sergipano" : 196773,
	"Brazil - Cup" : 1833,
	"Brazil - Paraense U20" : 217642,
	"Brazil - Copa Ouro U20" : 222976,
	"Brazil - Copa FMF" : 222573,
	"Brazil - Baiano" : 10769,
	"Brazil - Brasiliense" : 192841,
	"Brazil - Cearense 3" : 217644,
	"Brazil - Serie A Corners" : 6310,
	"Brazil - Copa Paulista" : 191548,
	"Brazil - Goiano U20" : 216061,
	"Brazil - Copa Do Nordeste" : 10883,
	"Brazil - Gaucho" : 1829,
	"Brazil - Potiguar" : 11681,
	"Brazil - Rio Cup" : 191543,
	"Brazil - Copa Paulista Women" : 230372,
	"Brazil - Sul-Matogrossense" : 218519,
	"Brazil - Mineiro 2" : 204522,
	"Brazil - Paranaense Women" : 215915,
	"Brazil - Sergipano Women" : 217663,
	"Brazil - Alagoano Women" : 215813,
	"Brazil - Amazonense U20" : 225927,
	"Brazil - Sergipano 2" : 216363,
	"Brazil - Sul-Matogrossense U20" : 236837,
	"Brazil - Baiano U20" : 213790,
	"Brazil - Paulista A3" : 203914,
	"Brazil - Carioca 2" : 194726,
	"Brazil - Paulista A4" : 201334,
	"Brazil - Catarinense 3" : 211197,
	"Brazil - Copa Gaucha" : 234332,
	"Brazil - Serie A Bookings" : 226748,
	"Brazil - U20 Cup" : 191805,
	"Brazil - Baiano 2" : 214197,
	"Brazil - Carioca Corners" : 72421,
	"Brazil - Brasileiro U20" : 210902,
	"Brazil - Carioca" : 1852,
	"Brazil - Carioca C" : 214754,
	"Brazil - Copa Goias U20" : 222593,
	"Brazil - Potiguar 2" : 211334,
	"Brazil - Tocantinense" : 217845,
	"Brazil - Paraibano U20" : 220106,
	"Brazil - Cearense" : 10768,
	"Brazil - Sergipano U20" : 214352,
	"Brazil - Mineiro" : 10778,
	"Brazil - Gaucho Women" : 216384,
	"Brazil - Brasileiro Women U20" : 224904,
	"Brazil - Paulista" : 2360,
	"Brazil - Capixaba Serie B" : 230332,
	"Brazil - Copa Ipiranga U20" : 207337,
	"Brazil - Campeonato U23" : 201718,
	"Brazil - Recopa Catarinense" : 233899,
	"Brazil - Catarinense 2" : 201811,
	"Brazil - Amazonense Serie B" : 216112,
	"Brazil - Supercopa Corners" : 224043,
	"Brazil - Copa Do Nordeste U20" : 207000,
	"Brazil - Cearense 2" : 211046,
	"Brazil - Pernambucano 2" : 202984,
	"Brazil - Serie B" : 1835,
	"Brazil - Amapaense Women" : 235426,
	"Brazil - Supercup Women" : 224350,
	"Brazil - Serie C" : 1836,
	"Brazil - Roraimense" : 218917,
	"Brazil - Cup Corners" : 192357,
	"Brazil - Brasileiro Women A3" : 220650,
	"Brazil - Piauiense Women" : 223275,
	"Brazil - Mato-Grossense" : 200573,
	"Brazil - Paulista Corners" : 192728,
	"Brazil - Catarinense U20" : 215782,
	"Brazil - Paulista A2" : 10782,
	"Brazil - Potiguar U20" : 216591,
	"Brazil - Amapaense" : 219613,
	"Brazil - Supercopa" : 218651,
	"Brazil - Pernambucano" : 10885,
	"Brazil - Matogrossense Women" : 222330,
	"Brazil - Alagoano" : 192685,
	"Brazil - Goiano 3" : 230303,
	"Brazil - Paraibano U19" : 215509,
	"Brazil - Paraense B1" : 216728,
	"Brazil - Paraense Women" : 222615,
	"Brazil - Pernambucano Women" : 206589,
	"Brazil - Serie D" : 201371,
	"Brazil - Piauiense U20" : 227000,
	"Brazil - Mineiro 3" : 215683,
	"Brazil - Catarinense" : 10776,
	"Brazil - Copa Santa Catarina U20" : 219549,
	"Brazil - Carioca B2 U20" : 236254,
	"Brazil - Copa Santa Catarina U21" : 227686,
	"Brazil - Brasileiro Women" : 201364,
	"Brazil - Carioca Women" : 211761,
	"Brazil - Copa Fares Lopes" : 197888,
	"Brazil - Piauiense" : 203930,
	"Brazil - Amazonense" : 218399,
	"Brazil - Baiano Women" : 215914,
	"Brazil - Carioca U20" : 210272,
	"Brazil - Amapaense U20" : 225342,
	"Brazil - Gaucho 2" : 201007,
	"Brazil - Mineiro U20" : 213318,
	"Brazil - U19" : 201479,
	"Brazil - Copa Grao Para" : 234751,
	"Brazil - Paraibano Women" : 211181,
	"Brazil - Mineiro Women" : 216258,
	"Brazil - Serie C Corners" : 220542,
	"Brazil - Alagoano 2" : 216237,
	"Brazil - Brasileiro Women A2" : 213513,
	"Brazil - Rondoniense" : 218691,
	"Brazil - Copa Verde" : 75455,
	"Brazil - Brasiliense Women" : 216550,
	"Brazil - Capixaba" : 218547,
	"Brazil - Pernambucano U20" : 210906,
	"Brazil - Copa Rio U20" : 216059,
	"Brazil - Matogrossense U20" : 225898,
	"Brazil - Serie B Corners" : 185632,
	"Brazil - Brasileiro U20 Corners" : 224985,
	"Brazil - Goiano" : 10780,
	"Brazil - Paulista U20" : 210903,
	"Brazil - Brasiliense U20" : 214172,
},

"Asia" : 
{
	"Qatar/UAE - Super Cup" : 234970,
	"SAFF - Championship Women" : 198238,
	"International - Premier League Asia Trophy" : 205800,
	"SAFF - Championship Corners" : 226483,
	"AFC - Champions League Qualifiers" : 7795,
	"EAFF - E-1 Championship Women" : 6435,
	"AFC - U20 Cup Qualifiers Women" : 197916,
	"World - J.League Asia Challenge" : 204013,
	"CAFA - Nations Cup" : 226330,
	"AFC - U17 Cup" : 226452,
	"WAFF - Championship U23" : 216345,
	"SAFF - Championship Women Under 19" : 234096,
	"AFC - U19 Championship" : 10085,
	"AFF - U23 Championship" : 218623,
	"AFC - U23 Asian Cup Qualification" : 216769,
	"CAFA - U20 Championship" : 206264,
	"AFC - Olympic Qualifiers Women" : 207935,
	"AFC - Olympic Qualifiers Women Corners" : 207936,
	"AFC - U20 Cup Qualifiers" : 222023,
	"AFF - Championship" : 1744,
	"AFF - U22 Championship" : 204225,
	"EAFF - E-1 Championship Women Corners" : 6437,
	"EAFF - E-1 Championship Corners" : 200291,
	"AFC - Champions League" : 1708,
	"AFC - U20 Cup" : 224527,
	"AFC - Cup" : 1709,
	"International - Premier League Asia Trophy Corner" : 205854,
	"AFC - Asian Cup Women Qualifiers" : 215865,
	"AFF - Championship Corners" : 223881,
	"FIFA - World Cup Qualifiers Asia" : 2014,
	"AFF - U19 Championship" : 197640,
	"AFC - Asian Cup" : 1707,
	"Asian Games U23 Corners" : 227848,
	"AFC - Arabian Gulf Cup" : 2090,
	"AFC - Cup Qualifiers" : 196889,
	"AFF - Women Championship" : 149046,
	"AFC - Asian Cup Qualifiers" : 198935,
	"AFC - U23 Cup Qualifiers" : 35180,
	"SAFF - Championship" : 192440,
	"AFC - U19 Championship Qualifiers" : 191734,
	"AFC - Asian Cup Women" : 8562,
	"EAFF - E-1 Championship" : 1939,
	"WAFF - Women's Championship" : 221873,
	"AFC - U23 Cup" : 35179,
},

"Senegal" : 
{
	"Senegal - FA Cup" : 215554,
	"Senegal - Ligue 1" : 217859,
},

"Poland" : 
{
	"Poland - Super Cup" : 5828,
	"Poland - Ekstraliga Women" : 163787,
	"Poland - 3rd Liga Group 2" : 216986,
	"Poland - Regional Cup" : 226409,
	"Poland - 3rd Liga Group 4" : 216988,
	"Poland - 3rd Liga Group 3" : 216987,
	"Poland - Ekstraklasa" : 2374,
	"Poland - Ekstraklasa Corners" : 6421,
	"Poland - Cup" : 2373,
	"Poland - U19 League" : 198670,
	"Poland - 1st Liga Corners" : 6985,
	"Poland - Cup Corners" : 191698,
	"Poland - 3rd Liga Group 1" : 201204,
	"Poland - 2nd Liga" : 2368,
	"Poland - 2nd Liga Women" : 216255,
	"Poland - 1st Liga" : 6633,
	"Poland - Cup Women" : 201398,
	"Poland - 1st Liga Women" : 212351,
	"Poland - 4th Liga" : 217281,
},

"Europe" : 
{
	"UEFA - U17 Championship Qualifiers" : 200033,
	"UEFA - Nations League B" : 200721,
	"UEFA - Youth League U19" : 6619,
	"UEFA - Super Cup" : 2636,
	"UEFA - U21 European Championship" : 2639,
	"UEFA - U17 Euro Championship" : 2637,
	"International - Emirates Cup Corners" : 187838,
	"FIFA - World Cup Qualifiers Europe" : 2015,
	"UEFA - Europa League" : 2630,
	"UEFA - Champions League Women" : 2642,
	"UEFA - U21 Euro Championship Qualifiers Corners" : 210342,
	"UEFA - U17 Euro Qualifiers Women" : 216121,
	"UEFA - EURO Women" : 2640,
	"UEFA - EURO Qualifiers" : 2635,
	"UEFA - Champions League Qualifiers" : 205451,
	"UEFA - U17 Championship Women" : 206948,
	"UEFA - U19 European Championship" : 2638,
	"UEFA CONMEBOL - Club Challenge" : 226909,
	"UEFA - EURO" : 5264,
	"FIFA - World Cup Qualifiers Europe Women" : 2012,
	"International - Baltic Cup" : 1801,
	"UEFA - U19 Euro Championship Qualifiers" : 5983,
	"UEFA - Nations League A" : 200719,
	"UEFA - Nations League D" : 200727,
	"UEFA - Europa League Qualifiers" : 2632,
	"UEFA - U21 Euro Championship Qualifiers" : 5982,
	"UEFA - U19 Euro Championship Women Qualifiers" : 2616,
	"UEFA - EURO Women Qualifiers" : 2641,
	"UEFA - Nations League C" : 200726,
	"UEFA - U19 Euro Championship Women" : 187792,
	"UEFA - Champions League" : 2627,
	"UEFA - Europa Conference League" : 214101,
},

"Portugal" : 
{
	"Portugal - Campeonato Group B" : 211059,
	"Portugal - Cup Women" : 207403,
	"Portugal - Campeonato Group A" : 211058,
	"Portugal - Super Cup" : 2381,
	"Portugal - League Cup Corners" : 10543,
	"Portugal - U23 Championship Corners" : 228133,
	"Portugal - League Cup Women" : 217689,
	"Portugal - Super Cup Corners" : 191409,
	"Portugal - U19 Championship" : 192537,
	"Portugal - Primeira Liga Corners" : 6600,
	"Portugal - Nacional Championship Women" : 196968,
	"Portugal - U23 Championship" : 202276,
	"Portugal - Campeonato Group D" : 211061,
	"Portugal - Cup" : 2384,
	"Portugal - Campeonato de Portugal Prio" : 202558,
	"Portugal - U23 Cup" : 204968,
	"Portugal - Campeonato Group C" : 211060,
	"Portugal - Cup Corners" : 217855,
	"Portugal - Super Cup Women" : 221395,
	"Portugal - 1st Division Women" : 196966,
	"Portugal - Liga 2" : 2387,
	"Portugal - Liga 2 Corners" : 6814,
	"Portugal - League Cup" : 4997,
	"Portugal - Campeonato Group F" : 211077,
	"Portugal - Liga 3" : 215023,
	"Portugal - Primeira Liga" : 2386,
	"Portugal - Campeonato Group E" : 211062,
},

"Netherlands" : 
{
	"Netherlands - Cup" : 1930,
	"Netherlands - Super Cup" : 1933,
	"Netherlands - Reserve League Cup" : 200650,
	"Netherlands - Cup Women" : 199332,
	"Netherlands - Eerste Divisie U19" : 202914,
	"Netherlands - Super Cup Corners" : 6439,
	"Netherlands - Eredivisie Women" : 192784,
	"Netherlands - Derde Divisie" : 218533,
	"Netherlands - Youth Cup U19" : 208317,
	"Netherlands - Eredivisie" : 1928,
	"Netherlands - Eerste Divisie Corners" : 6713,
	"Netherlands - U21 Divisie" : 209885,
	"Netherlands - Eredivisie Corners" : 6312,
	"Netherlands - Cup Corners" : 217810,
	"Netherlands - Reserve League" : 194765,
	"Netherlands - Tweede Divisie" : 202454,
	"Netherlands - Jong Eredivisie U19" : 194624,
	"Netherlands - Cup U21" : 234633,
	"Netherlands - Eerste Divisie" : 1929,
},

"UEFA" : 
{
	"UEFA - Nations League B Corners" : 200722,
	"UEFA - Nations League Women" : 227902,
	"UEFA - U21 Euro Championship Qualifier Corner" : 7014,
	"UEFA - Nations League B Bookings" : 202811,
	"UEFA - Europa League Bookings" : 185678,
	"UEFA - U21 European Championship Bookings" : 199391,
	"UEFA - Nations League A Corners" : 200720,
	"UEFA - Champions League Qualifiers Corners" : 205452,
	"UEFA - Europa League Qualifiers Bookings" : 205450,
	"UEFA - Super Cup Bookings" : 199604,
	"UEFA - Youth League U19 Corners" : 6912,
	"UEFA - EURO Women Corners" : 6408,
	"UEFA - Champions League Women Corners" : 197989,
	"UEFA - U21 European Championship Corners" : 6334,
	"UEFA - EURO Women Qualifiers Corners" : 208615,
	"UEFA - Europa Conference League Corners" : 215053,
	"UEFA - Nations League A Bookings" : 202810,
	"UEFA - Champions League Women Bookings" : 219813,
	"UEFA - Nations League Women Corners" : 227906,
	"UEFA - Nations League C Bookings" : 202812,
	"UEFA - EURO Qualifiers Bookings" : 204488,
	"UEFA - Europa League Corners" : 6263,
	"UEFA - EURO Qualifiers Corners" : 9749,
	"UEFA - Europa League Qualifiers Corners" : 9601,
	"UEFA - EURO Bookings" : 211315,
	"UEFA - Super Cup Corners" : 5880,
	"UEFA - U19 Euro Championship Women Corners" : 199605,
	"UEFA - Nations League D Bookings" : 202813,
	"UEFA - Champions League Corners" : 5452,
	"UEFA - Europa Conference League Bookings" : 215054,
	"UEFA - U19 Euro Championship Qualifiers Corners" : 10274,
	"UEFA - Champions League Bookings" : 16325,
	"UEFA - EURO Corners" : 211316,
	"UEFA - Champions League Qualifiers Bookings" : 205453,
	"UEFA - U19 European Championship Corners" : 6458,
	"UEFA - EURO Women Bookings" : 220681,
},

"USA" : 
{
	"USA - National Womens Soccer League Corners" : 220549,
	"USA - United Womens Soccer" : 201876,
	"International - Florida Cup" : 200509,
	"USA - Open Cup Corners" : 219645,
	"USA - Major League Soccer Corners" : 6301,
	"USA - USL League One" : 205322,
	"USA - Open Cup" : 2662,
	"USA - USL League 2" : 201642,
	"USA - Major League Soccer" : 2663,
	"USA - National Womens Soccer League Cup" : 209297,
	"USA - USL Championship Corners" : 206882,
	"USA - NPSL" : 201813,
	"USA - MLS Next Pro League" : 219120,
	"USA - Women Premier Soccer League" : 201730,
	"USA - NISA" : 206791,
	"USA - Major League Soccer Bookings" : 226736,
	"USA - National Womens Soccer League" : 201290,
	"USA - USL Cup" : 235928,
	"USA - NWSL Cup" : 209296,
	"USA - USL W League" : 219811,
	"USA - USL Championship" : 201065,
	"International - Florida Cup Corners" : 200556,
},

"Ireland" : 
{
	"Northern Ireland - Charity Shield" : 199591,
	"Northern Ireland - Premiership Women" : 201640,
	"Northern Ireland - Premiership Corners" : 198115,
	"Ireland - Super Cup" : 10954,
	"Ireland - Super Cup Corners" : 198582,
	"Ireland - League Cup Corners" : 191366,
	"Ireland - League Cup" : 2122,
	"Northern Ireland - Premiership" : 2259,
	"Ireland - Leinster Senior Cup" : 2125,
	"Northern Ireland - Premier Intermediate League" : 219323,
	"Northern Ireland - County Antrim Shield" : 192557,
	"Ireland - FAI Cup Women" : 221327,
	"Northern Ireland - League Cup" : 216406,
	"Ireland - National League Women" : 209852,
	"Northern Ireland - League Cup Corners" : 202801,
	"Northern Ireland - Championship" : 204919,
	"Ireland - Division 1 Corners" : 194804,
	"Ireland - FAI Cup Corners" : 196871,
	"Ireland - Munster Senior Cup" : 192706,
	"Ireland - Munster Senior League" : 222490,
	"Ireland - FAI Intermediate Cup" : 222761,
	"Ireland - U20 League" : 235146,
	"Ireland - U19 Cup" : 230541,
	"Northern Ireland - George Wilson Cup U20" : 205094,
	"Ireland - Leinster Senior Cup Corners" : 198471,
	"Ireland - Leinster Senior League" : 218223,
	"Northern Ireland - Cup" : 2258,
	"Northern Ireland - League Cup Women" : 220139,
	"Northern Ireland - Challenge Cup Women" : 201871,
	"Ireland - Division 1" : 2123,
	"Ireland - Munster Senior Cup Corners" : 198446,
	"Ireland - FAI Cup" : 2124,
	"Ireland - U19 League" : 197224,
	"Northern Ireland - Premiership Development League U20" : 202209,
	"Ireland - Premier Corners" : 6392,
	"Ireland - Premier" : 2120,
},

"Italy" : 
{
	"International - Viareggio Cup U19" : 204442,
	"Italy - Cup" : 2147,
	"Italy - Primavera Super Cup U19 Corners" : 227435,
	"Italy - Primavera 3 U19" : 212154,
	"Italy - Serie D Group A" : 212572,
	"Italy - Serie C Group A" : 217401,
	"Italy - Super Cup Women" : 218117,
	"Italy - Serie C Group C" : 217399,
	"Italy - Serie D Cup" : 201288,
	"Italy - Dante Berretti Championship" : 88182,
	"Italy - Serie C Group A Corners" : 227855,
	"Italy - Serie A Bookings" : 197440,
	"Italy - Serie C Group B Corners" : 227856,
	"Italy - Serie D Group E" : 212576,
	"Italy - Primavera U19" : 10227,
	"Italy - Primavera 4 U19" : 216379,
	"Italy - Primavera Women U19" : 212782,
	"Italy - Women Cup" : 207374,
	"Italy - Serie A Corners" : 5488,
	"Italy - Serie B Bookings" : 201809,
	"Italy - Serie D Group D" : 212575,
	"Italy - Serie D Group C" : 212574,
	"Italy - Cup Women" : 204055,
	"Italy - Serie C Corners" : 199869,
	"Italy - Serie C Group B" : 217400,
	"Italy - Serie C Group C Corners" : 227860,
	"Italy - Serie C" : 199868,
	"Italy - Serie D" : 200813,
	"Italy - Serie A" : 2436,
	"Italy - Serie A Women" : 203351,
	"Italy - Serie D Group G" : 212578,
	"Italy - Serie B Women" : 224160,
	"Italy - Serie C Super Cup" : 2148,
	"Italy - Serie C Cup Corners" : 194555,
	"Italy - Serie D Group F" : 212577,
	"Italy - Serie D Group H" : 212579,
	"Italy - Super Cup" : 2153,
	"Italy - Serie D Group I" : 212580,
	"Italy - Serie B" : 2438,
	"Italy - Serie C Cup" : 10806,
	"Italy - Serie D Group B" : 212573,
	"Italy - Cup Bookings" : 196870,
	"Italy - Cup Corners" : 6319,
	"Italy - Primavera Super Cup U19" : 227433,
	"Italy - Primavera 2 U19" : 207341,
	"Italy - Serie B Corners" : 5896,
	"Italy - Primavera Cup U19" : 10448,
	"Italy - Super Cup Corners" : 10455,
	"Italy - Super Cup Bookings" : 199618,
},

"India" : 
{
	"India - I-League" : 10578,
	"India - I-League U19" : 10636,
	"India - Mumbai Super Division" : 230704,
	"India - Regional Cup" : 218171,
	"India - Rajasthan League A Division" : 234701,
	"India - I-League 2" : 201143,
	"India - U18 League" : 207395,
	"India - Shillong Premier League" : 200283,
	"India - Calcutta Premier Division" : 202235,
	"India - League Women" : 233892,
	"India - Bangalore Super Division" : 212179,
	"India - Santosh Trophy" : 204696,
	"India - Goa Professional League" : 10353,
	"India - Chennai Senior Division" : 219727,
	"India - Mumbai Elite Division League Corners" : 200426,
	"India - IFA Shield" : 211144,
	"India - MFA Super Cup" : 225348,
	"India - Super Cup Corners" : 204472,
	"India - Durand Cup" : 221690,
	"India - Mumbai Elite Division League" : 192535,
	"India - Punjab League" : 211317,
	"India - Super Cup" : 201000,
	"India - I-League Corners" : 198302,
	"India - Manipur State League" : 212648,
	"India - Delhi League Women" : 217989,
	"India - Sikkim Premier League" : 224672,
	"India - Delhi Premier League" : 216397,
	"India - Mizoram Premier League" : 222241,
	"India - Super League" : 10083,
	"India - Super League Corners" : 198033,
},

"Hungary" : 
{
	"Hungary - NB 3" : 208665,
	"Hungary - Cup Women" : 219027,
	"Hungary - NB 1 Women" : 203318,
	"Hungary - Cup" : 2096,
	"Hungary - NB 3 Centre" : 224383,
	"Hungary - NB 2 Corners" : 226731,
	"Hungary - NB 2" : 201214,
	"Hungary - NB 1" : 2095,
	"Hungary - U19 League" : 201200,
	"Hungary - Cup Corners" : 218791,
	"Hungary - NB 1 Corners" : 69875,
	"Hungary - NB 3 East" : 224382,
	"Hungary - NB 3 West" : 224384,
	"Hungary - U19 Alap" : 213507,
},

"Indonesia" : 
{
	"Indonesia - Menpora Cup" : 212701,
	"Indonesia - Liga 1 Corners" : 201161,
	"Indonesia - Cup" : 200201,
	"Indonesia - Presidents Cup" : 191920,
	"Indonesia - Liga 2" : 201493,
	"Indonesia - Liga 1" : 199211,
	"Indonesia - Presidents Cup Corners" : 200760,
	"Indonesia - Liga 3" : 216910,
},

"Southeast Asia" : 
{
	"SEA Games - Womens" : 207260,
	"SEA Games - Mens" : 185680,
	"SEA Games - Corners" : 207245,
},

"World" : 
{
	"International - Friendlies U19 Corners" : 198385,
	"Friendly - World Club" : 2674,
	"International - Merlion Cup U22" : 205340,
	"International - Champions Cup Women" : 206309,
	"International - Algarve Cup Women Corners" : 208729,
	"International - Friendlies Women Corners" : 72435,
	"FIFA - World Cup U17" : 2608,
	"International - Friendlies Bookings" : 48008,
	"International - Intercontinental Cup" : 226402,
	"International - Friendlies U23 Corners" : 199227,
	"FIFA - World Cup" : 2686,
	"FIFA - World Cup Qualifiers Asia Bookings" : 205335,
	"International - Friendlies U20" : 2113,
	"UEFA - U19 Euro Championship Women Qualifiers Corners" : 201163,
	"International - Cup of Champions" : 219187,
	"International - Intercontinental Cup Corners" : 226404,
	"International - Finalissima Women" : 225078,
	"FIFA - World Cup Extra Time" : 9102,
	"FIFA - World Cup Women Bookings" : 205336,
	"International - Friendlies Women" : 2116,
	"International - Friendlies U22 Corners" : 226445,
	"FIFA - World Cup Qualifiers Intercontinental" : 219415,
	"Friendlies" : 2038,
	"AFC - U20 Cup Women" : 207121,
	"FIFA - World Cup U17 Women" : 4483,
	"International - Cup of Champions Corners" : 220002,
	"UEFA CONMEBOL - Club Challenge Corners" : 226911,
	"International - Friendlies" : 2117,
	"UEFA CONMEBOL - Club Challenge Bookings" : 226912,
	"International - Valeriy Lobanovskiy Memorial Corners" : 205274,
	"International - Friendlies U23 Women" : 10937,
	"Club Friendlies Women" : 1864,
	"World - Seniors Championship" : 225488,
	"FIFA - World Cup U20 Women" : 2010,
	"International - Baltic Cup U19" : 220144,
	"WAFU - Cup of Nations U20" : 226786,
	"International - Memorial Valentin Granatkin Corners" : 205275,
	"International - Maurice Revello Youth Tournament" : 2562,
	"International - Friendlies U19 Women" : 10982,
	"International - Baltic League Women" : 223044,
	"FIFA - World Cup U20 Women Qualifiers" : 233204,
	"International - Islamic Solidarity Games U23" : 221392,
	"International - Kirin Cup Corners" : 196935,
	"International - Sud Ladies Cup U20" : 220513,
	"Club Friendlies Corners" : 10608,
	"International - Friendlies U19" : 2112,
	"International - Friendlies U18" : 206693,
	"International - Merlion Cup U22 Corners" : 205341,
	"International - Friendlies U23" : 2115,
	"FIFA - World Cup Qualifiers Women" : 224313,
	"International - SheBelieves Cup Women Corners" : 208606,
	"Central American and Caribbean Games U22" : 226600,
	"International - SheBelieves Cup Women" : 204340,
	"International - Algarve Cup Women" : 7953,
	"International - Emirates Cup" : 1950,
	"International - Friendlies U19 Women Corners" : 198361,
	"International - Valeriy Lobanovskiy Memorial" : 205270,
	"World - Mediterranean Games" : 201922,
	"International - Premier League Cup U21" : 222733,
	"Friendly - U19" : 2039,
	"International - Memorial Valentin Granatkin" : 205271,
	"FIFA - Arab Cup" : 213780,
	"International - Friendlies U22" : 226443,
	"FIFA - Beach Soccer World Cup (Reg. Time - 3x12 mins)" : 215048,
	"WAFU - Cup" : 199733,
	"FIFA - World Cup U20" : 2620,
	"Central American and Caribbean Games - Women" : 226518,
	"Friendly - Women" : 2042,
	"FIFA - World Cup Women" : 2687,
	"CAF - Africa Cup of Nations U23 Corners" : 204534,
	"FIFA - Club World Cup" : 1865,
	"FIFA - World Cup Women Qualifiers Europe" : 198974,
	"International - Friendlies U20 Corners" : 197975,
	"International - Friendlies U21" : 2114,
	"International - Friendlies U20 Women" : 197705,
	"Dubai Challenge Cup" : 1926,
	"International - Friendlies Corners" : 6323,
	"International - Kirin Cup" : 2179,
	"International - Friendlies U21 Corners" : 48006,
	"International - Finalissima Women Corners" : 225160,
	"CONCACAF - Nations League Corners" : 206572,
	"International - Maurice Revello Youth Tournament Corners" : 205272,
	"International - Baltic Cup U19 Women" : 226658,
	"Club Friendlies" : 1863,
	"International - Baltic Cup U21" : 236061,
	"International - Cup of Champions Bookings" : 220004,
},

"Austria" : 
{
	"Austria - Regionalliga Cup" : 204803,
	"Austria - Landesliga" : 201501,
	"Austria - Regionalliga West" : 1786,
	"Austria - 2. Liga Corners" : 6775,
	"Austria - Bundesliga Women" : 194738,
	"Austria - Regionalliga West Corners" : 192151,
	"Austria - Regionalliga Vorarlberg" : 219057,
	"Austria - Bundesliga Corners" : 6299,
	"Austria - BFV Cup" : 216776,
	"Austria - 2. Liga" : 1773,
	"Austria - Cup" : 1776,
	"Austria - Regionalliga Mitte Corners" : 192150,
	"Austria - Regionalliga Mitte" : 1785,
	"Austria - Regionalliga Salzburg" : 206230,
	"Austria - TFV Cup" : 219528,
	"Austria - Bundesliga" : 1792,
	"Austria - Bundesliga 2 Women" : 210707,
	"Austria - WFV Cup" : 207264,
	"Austria - Regionalliga Ost" : 1784,
	"Austria - Regionalliga Ost Corners" : 192152,
	"Austria - STFV Steirercup" : 207201,
	"Austria - Cup Corners" : 76258,
	"Austria - KFV Cup" : 207193,
	"Austria - VFV Cup" : 220080,
	"Austria - Regionalliga Tirol" : 206303,
	"Austria - Womens Cup" : 205367,
},

"Bosnia and Herzegovina" : 
{
	"Bosnia and Herzegovina - Premier Liga" : 1826,
	"Bosnia and Herzegovina - Cup" : 198700,
	"Bosnia and Herzegovina - 1st League" : 210572,
	"Bosnia and Herzegovina - Regional Cup" : 219321,
	"Bosnia and Herzegovina - Premier League Women" : 216148,
},

"Turkey" : 
{
	"Turkey - 1. Lig U19" : 228208,
	"Turkey - Super Cup Corners" : 191395,
	"Turkey - Super Lig U19" : 228207,
	"Turkey - 1st League" : 2578,
	"International - Turkish Women's Cup" : 204311,
	"Turkey - Cup Corners" : 217988,
	"Turkey - U21 League" : 202625,
	"Turkey - Super Cup" : 2597,
	"Turkey - 3rd League Group 1" : 217332,
	"Turkey - 3rd League" : 235357,
	"Turkey - 2nd League" : 208269,
	"Turkey - 1st League Corners" : 192416,
	"Turkey - Reserve League" : 221695,
	"Turkey - Super League Women" : 208265,
	"Turkey - 3rd League Group 2" : 210164,
	"Turkey - 3rd League Group 4" : 227694,
	"International - Alanya Cup" : 200938,
	"Turkey - 1st League Women" : 223597,
	"Turkey - Super League" : 2592,
	"Turkey - Super League Corners" : 6811,
	"Turkey - Cup" : 2586,
	"Turkey - 3rd League Group 3" : 217333,
},

"Spain" : 
{
	"Spain - Copa Catalunya" : 2469,
	"Spain - Federation Cup" : 192507,
	"Spain - Tercera Division Group 10" : 204818,
	"Spain - La Liga" : 2196,
	"Spain - Tercera Division Group 16" : 204824,
	"Spain - Copa del Rey Bookings" : 198461,
	"Spain - Primera RFEF Group 1 Corners" : 228213,
	"Spain - Tercera Division Group 5" : 204813,
	"Spain - Segunda B Group 4 Corners" : 207648,
	"Spain - Segunda B Group 2 Corners" : 207646,
	"Spain - Tercera Division Group 1" : 204809,
	"Spain - Tercera Division Group 15" : 204823,
	"Spain - Tercera Division Group 12" : 204820,
	"Spain - Tercera Division Group 4" : 204812,
	"Spain - U19 League" : 201069,
	"Spain - Regional Leagues" : 226206,
	"Spain - Tercera Division Group 3" : 204811,
	"Spain - Primera Division Women Cup" : 197059,
	"Spain - Tercera Division Group 9" : 204817,
	"Spain - La Liga Corners" : 5490,
	"Spain - Primera Division Women" : 2468,
	"Spain - Supercopa Catalunya" : 197898,
	"Spain - Primera Division Women Corners" : 218659,
	"Spain - Cup U19" : 218221,
	"Spain - Tercera Division Group 8" : 204816,
	"Spain - Tercera Federacion Women" : 211977,
	"Spain - Primera RFEF Group 2" : 218702,
	"Spain - Primera Federacion Women" : 222018,
	"Spain - Super Cup" : 2463,
	"Spain - Segunda B Group 3 Corners" : 207647,
	"Spain - Tercera Division Group 7" : 204815,
	"Spain - Primera RFEF Group 1" : 215328,
	"Spain - Copa del Rey Corners" : 6735,
	"Spain - Copa Catalunya Women" : 202310,
	"Spain - Tercera Division" : 199926,
	"Spain - Cup Women" : 199337,
	"Spain - Segunda RFEF Group 3" : 2466,
	"Spain - Tercera Division Group 13" : 204821,
	"Spain - Tercera Division Group 14" : 204822,
	"Spain - Segunda B Group 5 Corners" : 210453,
	"Spain - Super Cup Women" : 218265,
	"Spain - Segunda RFEF Group 5" : 210452,
	"Spain - Segunda RFEF Playoffs" : 2429,
	"Spain - Primera RFEF Group 2 Corners" : 228215,
	"Spain - Tercera Division Group 2" : 204810,
	"Spain - Tercera Division Group 18" : 204826,
	"Spain - Tercera Division Group 11" : 204819,
	"Spain - Segunda RFEF Group 1" : 2464,
	"Spain - Tercera Division Group 17" : 204825,
	"Spain - Segunda Division Corners" : 5898,
	"Spain - Segunda RFEF Group 4" : 2467,
	"Spain - Super Cup Bookings" : 199615,
	"Spain - Super Cup Corners" : 5878,
	"Spain - Tercera Division Group 6" : 204814,
	"Spain - U19 Cup Corners" : 205241,
	"Spain - Segunda Division" : 2432,
	"Spain - Federation Cup Corners" : 198383,
	"Spain - Segunda RFEF Group 2" : 2465,
	"Spain - Tercera Division Corners" : 207227,
	"Spain - Primera RFEF" : 220076,
	"Spain - Segunda Federacion Women" : 222019,
	"Spain - Copa del Rey" : 2462,
	"Spain - Segunda División RFEF" : 215547,
	"Spain - La Liga Bookings" : 32746,
	"Spain - Segunda B" : 10317,
	"Spain - Segunda B Group 1 Corners" : 207645,
},

"England" : 
{
	"England - EFL Cup" : 1982,
	"England - Premier League Cup U21" : 200047,
	"England - EFL Cup Corners" : 6834,
	"England - Premier League Cup U21 Corners" : 225213,
	"England - Central League Reserves" : 200809,
	"England - Lincolnshire Senior Cup" : 203131,
	"England - National League North Corners" : 201319,
	"England - National League" : 1978,
	"England - FA Trophy" : 1983,
	"England - Professional Development League U21 Corners" : 224987,
	"England - Championship" : 1977,
	"England - League 2" : 1958,
	"England - Oxfordshire Senior Cup" : 204917,
	"England - Women Super League Corners" : 207218,
	"England - Championship Corners" : 5938,
	"England - Isthmian Division 1 South" : 191446,
	"England - League 2 Corners" : 42016,
	"England - Premier League 2 U21" : 197646,
	"England - Hampshire Senior Cup" : 218119,
	"England - Counties Leagues" : 210421,
	"England - North West Counties League Premier" : 207266,
	"England - Non League Division One" : 228141,
	"England - Championship Bookings" : 202195,
	"England - Northern Premier League Challenge Cup" : 192488,
	"England - Staffordshire Senior Cup" : 203851,
	"England - FA Cup Women" : 1981,
	"England - FA Vase" : 213115,
	"England - Southern Premier League Corners" : 201323,
	"England - League Cup Women" : 207075,
	"England - EFL Trophy" : 197559,
	"England - West Riding County Cup" : 192098,
	"England - FA Women's National League Cup" : 227473,
	"England - Premier League 2 U21 Corners" : 198002,
	"England - Community Shield Bookings" : 206151,
	"England - Kent Senior Cup" : 202290,
	"England - Northern Premier League Cup" : 197654,
	"England - EFL Cup Bookings" : 198641,
	"England - Southern Football League Cup" : 10555,
	"England - Essex Senior Cup" : 198357,
	"England - Championship Women" : 206343,
	"England - Sussex Senior Challenge Cup" : 207115,
	"England - London Senior Cup" : 192237,
	"England - Community Shield Corners" : 6516,
	"England - National League South" : 1952,
	"England - FA Community Shield Women" : 209836,
	"England - Southern Premier League" : 11695,
	"England - FA Trophy Corners" : 192109,
	"England - FA Cup Corners" : 6276,
	"England - Women Super League" : 8713,
	"England - Non League Premier" : 206992,
	"England - Isthmian Division 1 SE" : 207693,
	"England - Women Super League Cup Corners" : 207222,
	"England - Northern Premier League" : 11693,
	"England - Community Shield" : 1953,
	"England - Premier League U21 Corners" : 6682,
	"England - Hertfordshire Senior Challenge Cup" : 208162,
	"England - Isthmian Premier League" : 11697,
	"England - Lancashire Senior Cup" : 201229,
	"England - Isthmian Division 1 North" : 191445,
	"England - East Riding Senior Cup" : 204930,
	"England - Sheffield & Hallamshire Senior Cup" : 201477,
	"England - Surrey Senior Cup" : 218717,
	"England - National League North" : 1951,
	"England - FA Cup Women Corners" : 225821,
	"England - Northern Premier League Division 1" : 201373,
	"England - Liverpool Senior Cup" : 197377,
	"England - National League Corners" : 6678,
	"England - Southern Football League Division 1" : 201331,
	"England - FA Trophy Qualification" : 222069,
	"England - Manchester Premier Cup" : 198178,
	"England - BBFA Senior Cup" : 203878,
	"England - Derbyshire Senior Cup" : 10551,
	"England - FA Cup Qualification" : 214745,
	"England - National League South Corners" : 207440,
	"England - Central League Cup Reserves" : 201481,
	"England - Walsall Senior Cup" : 192096,
	"England - National League Women" : 206582,
	"England - Norfolk Senior Cup" : 204915,
	"England - Premier League Corners" : 5487,
	"England - Premier League Bookings" : 197438,
	"England - Middlesex Senior Cup" : 207405,
	"England - Premier League" : 1980,
	"England - Professional Development League U21" : 198316,
	"England - Alan Turvey Trophy" : 202288,
	"England - EFL Trophy Corners" : 198137,
	"England - Cheshire Senior Cup" : 10553,
	"England - FA Cup Bookings" : 198704,
	"England - Lancashire FA Challenge Trophy" : 207114,
	"England - Northamptonshire Senior Cup" : 192235,
	"England - Birmingham Senior Cup" : 201309,
	"England - Isthmian Premier League Corners" : 192153,
	"England - League 1" : 1957,
	"England - League 1 Corners" : 6303,
	"England - FA Cup" : 1979,
},

"Croatia" : 
{
	"International - Croatia Cup Women" : 198680,
	"Croatia - Cup Corners" : 200145,
	"Croatia - Super Cup" : 205799,
	"Croatia - HNL Corners" : 72427,
	"Croatia - Cup" : 1882,
	"Croatia - Super Cup Corners" : 220705,
	"Croatia - 3. NL" : 222092,
	"Croatia - U19 Cup" : 234591,
	"Croatia - U19 League" : 201199,
	"Croatia - Prva NL" : 1881,
	"Croatia - 2. NL" : 201210,
	"Croatia - 1. HNL Women" : 210375,
	"Croatia - HNL" : 1880,
},

"Bolivia" : 
{
	"Bolivia - Primera Division Corners" : 198062,
	"Bolivia - Primera Division" : 5595,
	"Bolivia - Copa Division Profesional" : 224467,
	"Bolivia - Reserve League" : 215038,
	"Bolivia - Cup" : 197206,
	"Bolivia - Copa Simon Bolivar" : 202770,
},

"Lebanon" : 
{
	"Lebanon - Super Cup" : 227023,
	"Lebanon - Premier League" : 2205,
},

"Belgium" : 
{
	"International - Baltic Cup Corners" : 201696,
	"Belgium - Challenger Pro League" : 1818,
	"Belgium - Women Cup" : 207199,
	"Belgium - Super League Women" : 196778,
	"Belgium - Super Cup" : 1816,
	"Belgium - Cup" : 1819,
	"Belgium - First Amateur Division" : 202447,
	"Belgium - Reserve Pro League U21" : 209638,
	"Belgium - Pro League Corners" : 6486,
	"Belgium - 2nd Amateur Division" : 218689,
	"Belgium - Reserve Pro League Cup U21" : 216393,
	"Belgium - Challenger Pro League Corners" : 10336,
	"Belgium - Super Cup Corners" : 197300,
	"Belgium - Pro League" : 1817,
	"Belgium - Youth League U21" : 10254,
	"Belgium - Cup Corners" : 217854,
},

"Australia" : 
{
	"Australia - A League Bookings" : 48010,
	"Australia - Queensland Premier League Women" : 219046,
	"Australia - Northern NSW Reserves League" : 209387,
	"Australia - FFT League Cup" : 197539,
	"Australia - Cup Corners" : 218234,
	"Australia - Brisbane Silver Boot" : 200504,
	"Australia - Tasmania Summer Cup" : 208141,
	"Australia - South Australia State League 2" : 216618,
	"Australia - NPL Capital Territory" : 8592,
	"Australia - NPL Tasmania" : 163720,
	"Australia - Queensland Premier League 3" : 220087,
	"Australia - Cup" : 9394,
	"Australia - Northern NSW State League 1" : 201448,
	"Australia - NPL Queensland U23" : 208181,
	"Australia - Victoria Premier League 1 U23" : 224649,
	"Australia - NPL 3 Victoria" : 212505,
	"Australia - NPL Reserves" : 209685,
	"Australia - NPL Queensland" : 8584,
	"Australia - South Australia State League 1" : 194630,
	"Australia - State Cup Women" : 197317,
	"Australia - Western Australia State League 1" : 219117,
	"Australia - NPL Northern NSW Corners" : 220540,
	"Australia - Queensland Premier League 3 U23" : 201895,
	"Australia - NPL New South Wales Corners" : 220538,
	"Australia - Western Australia Cup" : 9318,
	"Australia - Queensland Premier League 4" : 10914,
	"Australia - NPL South Australia Women" : 220553,
	"Australia - NorZone Premier League" : 209510,
	"Australia - Victoria Premier League Women" : 35177,
	"Australia - A League" : 1766,
	"Australia - NPL 2 Western Australia" : 201197,
	"Australia - NPL Northern NSW Women" : 220556,
	"Australia - A-League Women Corners" : 198014,
	"Australia - NPL 2 New South Wales U20" : 220658,
	"Australia - NPL Victoria Women" : 220558,
	"Australia - South Australia Premier League Reserve" : 201920,
	"Australia - Queensland Premier League" : 213666,
	"Australia - PSC Championship" : 207717,
	"Australia - NPL Queensland Corners" : 220534,
	"Australia - NPL Western Australia Women" : 220565,
	"Australia - Victoria Premier League 1" : 1756,
	"Australia - Victoria Cup Women" : 219373,
	"Australia - Gold Coast Premier League" : 210830,
	"Australia - NPL New South Wales U20" : 220661,
	"Australia - NPL 2 Capital Territory" : 201449,
	"Australia - South Australia State League 1 Reserves" : 209831,
	"Australia - NPL South Australia Women Reserve" : 224931,
	"Australia - SA Cup Women" : 204066,
	"Australia - NPL Western Australia" : 8586,
	"Australia - NPL Western Australia U20" : 220659,
	"Australia - Cup Bookings" : 218528,
	"Australia - NPL Western Australia Corners" : 66352,
	"Australia - Tasmania Southern Championship" : 204673,
	"Australia - Northern NSW State League 1 Reserves" : 204675,
	"Australia - Tasmania Northern Championship" : 214014,
	"Australia - Northern Football" : 120869,
	"Australia - NPL Queensland Women" : 220555,
	"Australia - A League Corners" : 6782,
	"Australia - NPL New South Wales Women" : 220562,
	"Australia - Cup Qualifiers" : 10984,
	"Australia - Western Australia Night Series Women" : 212409,
	"Australia - Western Australia Night Series" : 194565,
	"Australia - Victoria State League 1" : 219672,
	"Australia - NPL 2 Queensland" : 200697,
	"Australia - NPL Victoria Corners" : 220532,
	"Australia - NPL Capital Territory Youth U23" : 209537,
	"Australia - A-League Women" : 10030,
	"Australia - NPL Northern NSW" : 8594,
	"Australia - New South Wales League 2" : 212331,
	"Australia - New South Wales League 1" : 194796,
	"Australia - Brisbane Premier League" : 1749,
	"Australia - NPL Victoria U23" : 218678,
	"Australia - Queensland Premier League 2" : 214179,
	"Australia - Western Australia State League 1 Reserves" : 220384,
	"Australia - NPL Finals" : 9913,
	"Australia - Queensland Pro Series" : 224369,
	"Australia - Brisbane Premier League Women" : 216079,
	"Australia - NPL Capital Territory Women" : 220554,
	"Australia - NPL New South Wales" : 8588,
	"Australia - NPL South Australia Corners" : 220536,
	"Australia - Western Australia State League Night Series" : 214554,
	"Australia - Western Australia Cup Women" : 220251,
	"Australia - Brisbane Cup Women" : 213339,
	"Australia - Queensland Premier League U23" : 219500,
	"Australia - NPL Capital Territory Corners" : 220825,
	"Australia - Victoria Dockerty Cup" : 8826,
	"Australia - Tasmania Super League Women" : 215395,
	"Australia - Tasmania Cup Women" : 225207,
	"Australia - NPL South Australia" : 1753,
	"Australia - Queensland Cup Women" : 213338,
	"Australia - NPL Victoria" : 1769,
	"Australia - NPL Tasmania U21" : 224934,
	"Australia - Brisbane Cup" : 8709,
	"Australia - NSW Cup" : 8653,
	"Australia - NPL Tasmania Corners" : 220823,
	"Australia - FFV Community Shield" : 204152,
},

"Sweden" : 
{
	"Sweden - Damallsvenskan Corners" : 201263,
	"Sweden - Damallsvenskan" : 1903,
	"Sweden - 2nd Div. Norra Gotaland Corners" : 192143,
	"Sweden - Cup Corners" : 213502,
	"Sweden - Women Cup" : 204223,
	"Sweden - Elitettan Women" : 210423,
	"Sweden - Superettan" : 2476,
	"Sweden - 2nd Div. Sodra Gotaland" : 2484,
	"Sweden - 2nd Div. Norra Gotaland" : 191455,
	"Sweden - Superettan Bookings" : 201750,
	"Sweden - Division 1" : 2506,
	"Sweden - 2nd Div. Norra Svealand Corners" : 192144,
	"Sweden - Division 1 Sodra" : 2513,
	"Sweden - Division 1 Sodra Corners" : 197263,
	"Sweden - Allsvenskan Bookings" : 202789,
	"Sweden - U21 League" : 2514,
	"Sweden - 2nd Div. Vastra Gotaland Corners" : 192148,
	"Sweden - Super Cup" : 2512,
	"Sweden - Superettan Corners" : 6388,
	"Sweden - Division 2" : 223188,
	"Sweden - Cup" : 2516,
	"Sweden - 2nd Div. Ostra Gotaland" : 2483,
	"Sweden - 2nd Div. Vastra Gotaland" : 2486,
	"Sweden - 2nd Div. Sodra Svealand Corners" : 192147,
	"Sweden - Division 1 Norra Corners" : 197261,
	"Sweden - 2nd Div. Norra Svealand" : 2481,
	"Sweden - 2nd Div. Sodra Svealand" : 2485,
	"Sweden - 2nd Div. Sodra Gotaland Corners" : 192146,
	"Sweden - 2nd Div. Norrland Corners" : 192145,
	"Sweden - Division 1 Norra" : 2510,
	"Sweden - Allsvenskan" : 1728,
	"Sweden - 2nd Div. Norrland" : 2487,
	"Sweden - Allsvenskan Corners" : 6269,
},

"North America" : 
{
	"CONCACAF - U20 Championship" : 4787,
	"North America - Campeones Cup Corners" : 227963,
	"FIFA - World Cup Qualifiers CONCACAF" : 212593,
	"North America - Leagues Cup" : 205939,
	"FIFA - World Cup Qualifiers North America" : 2017,
	"North America - Leagues Cup Corners" : 205940,
	"North America - Campeones Cup" : 227961,
	"CONCACAF - Nations League" : 206571,
	"CONCACAF - Central American Games W" : 200297,
	"CONCACAF - Nations League - Qualifiers" : 202502,
	"CONCACAF - League" : 199581,
	"CONCACAF - N/C America Women's WC Qualification" : 201628,
	"CONCACAF - Gold Cup" : 2077,
	"CONCACAF - Olympic Qualifiers" : 212499,
	"North America - Leagues Cup Bookings" : 227152,
	"CONCACAF - Olympic Qualifiers Women Corners" : 207939,
	"CONCACAF - Champions Cup" : 1870,
	"CONCACAF - Gold Cup Qualifiers" : 35185,
	"CONCACAF - U20 Championship Qualifiers Women" : 225295,
	"CONCACAF - Championship Women" : 220568,
	"CONCACAF - Gold Cup Bookings" : 214571,
	"CONCACAF - U20 Championship Women" : 199440,
	"CONCACAF - Caribbean Cup" : 204985,
	"CONCACAF - Olympic Qualifiers Women" : 206788,
},

"Uruguay" : 
{
	"Uruguay - Super Cup Corners" : 224144,
	"Uruguay - Primera Division" : 5593,
	"Uruguay - Cup" : 5594,
	"Uruguay - Super Cup" : 218468,
	"Uruguay - Primera Division Corners" : 198494,
	"Uruguay - U19 League" : 214812,
	"Uruguay - Cup Corners" : 223042,
	"Uruguay - Reserve League" : 214839,
	"Uruguay - Amateur Cup" : 225854,
	"Uruguay - Segunda Division" : 205369,
	"Uruguay - Segunda B Nacional" : 222660,
},

"Jordan" : 
{
	"Jordan - Pro League" : 9902,
	"Jordan - Super Cup" : 191461,
	"Jordan - Pro League Women" : 222242,
	"Jordan - Pro League Corners" : 72433,
	"Jordan - Cup" : 2167,
	"Jordan - Shield Cup" : 2169,
	"Jordan - 1st Division" : 201147,
},

"Oman" : 
{
	"Oman - 1st Division" : 216620,
	"Oman - Super Cup" : 233460,
	"Oman - Pro League" : 210715,
	"Oman - Cup" : 2352,
},

"Myanmar" : 
{
	"Myanmar - National League 2" : 222452,
	"Myanmar - Cup" : 234356,
	"Myanmar - National League" : 210126,
	"Myanmar - Women League" : 223067,
},

"Bulgaria" : 
{
	"Bulgaria - First League" : 9320,
	"Bulgaria - Third League" : 209887,
	"Bulgaria - Second League" : 202119,
	"Bulgaria - First League Corners" : 198082,
	"Bulgaria - Cup" : 1839,
	"Bulgaria - Super Cup" : 9503,
	"Bulgaria - Cup Corners" : 201343,
	"Bulgaria - Women League" : 205436,
	"Bulgaria - U19 League" : 202333,
},

"Iceland" : 
{
	"Iceland - Super Cup Corners" : 225084,
	"Iceland - 2. Deild Women" : 220346,
	"Iceland - U19 League Cup" : 200821,
	"Iceland - Fotbolt-i.net Cup Corners" : 198329,
	"Iceland - 4. Deild" : 201897,
	"Iceland - 3. Deild" : 201869,
	"Iceland - Cup Corners" : 199103,
	"Iceland - Faxafloi U19" : 218610,
	"Iceland - U19 League" : 196933,
	"Iceland - Premier League Corners" : 187705,
	"Iceland - 1. Deild" : 2100,
	"Iceland - 2. Deild" : 197293,
	"Iceland - Cup Women" : 201242,
	"Iceland - Pre-Season Cup" : 233306,
	"Iceland - League Cup B" : 204304,
	"Iceland - Reykjavik Cup Women" : 218256,
	"Iceland - League Cup Women A" : 211965,
	"Iceland - Super Cup" : 201333,
	"Iceland - 1. Deild Corners" : 206591,
	"Iceland - Reykjavik Cup U19" : 218612,
	"Iceland - League Cup Women C" : 219003,
	"Iceland - League Cup C" : 208351,
	"Iceland - League Cup" : 4994,
	"Iceland - Super Cup Women" : 219363,
	"Iceland - Cup" : 2101,
	"Iceland - League Cup Corners" : 192819,
	"Iceland - League Cup Women B" : 218790,
	"Iceland - Urvalsdeild Women" : 197088,
	"Iceland - Premier League" : 2102,
	"Iceland - Fotbolti.net Cup" : 10509,
	"Iceland - Reykjavik Cup" : 192494,
	"Iceland - 1. Deild Women" : 197236,
	"Iceland - U19 League Woman" : 205438,
	"Iceland - Reykjavik Cup Corners" : 198312,
	"Iceland - 5. Deild" : 225824,
	"Iceland - Faxafloi Cup Women" : 218185,
},

"Luxembourg" : 
{
	"Luxembourg - Promotion D Honneur" : 222319,
	"Luxembourg - Cup" : 196904,
	"Luxembourg - National Division" : 2228,
},

"Norway" : 
{
	"Norway - 3rd Division Group 4" : 216991,
	"Norway - 3rd Division Group 5" : 216992,
	"Norway - Cup Women" : 2281,
	"Norway - 1st Division Women" : 201957,
	"Norway - 3rd Division Group 2" : 216989,
	"Norway - U19 League" : 201238,
	"Norway - Toppserien Women Corners" : 199277,
	"Norway - PostNord Cup" : 210447,
	"Norway - Eliteserien" : 2333,
	"Norway - 1st Division Corners" : 6816,
	"Norway - Super Cup" : 198947,
	"Norway - Eliteserien Corners" : 5888,
	"Norway - Cup Corners" : 191419,
	"Norway - 3rd Division Group 3" : 216990,
	"Norway - 2nd Division" : 2332,
	"Norway - U19 Cup" : 203037,
	"Norway - Cup" : 2280,
	"Norway - 3rd Division Group 6" : 216993,
	"Norway - 1st Division" : 2331,
	"Norway - 3rd Division Group 1" : 201285,
	"Norway - Super Cup Corners" : 201375,
	"Norway - 2nd Division Corners" : 207234,
	"Norway - Toppserien Women" : 196861,
},

"South America" : 
{
	"CONMEBOL - South American Youth Games U20" : 201677,
	"CONMEBOL - Copa America" : 1872,
	"CONMEBOL - U17 Championship Women" : 218795,
	"CONCACAF - Nations League Bookings" : 213560,
	"CONMEBOL - Recopa Sudamericana" : 2394,
	"CONMEBOL - Copa America Femenina" : 201194,
	"CONMEBOL - Pre-Olympic Tournament U23 Corners" : 207688,
	"CONMEBOL - Copa Libertadores Femenina" : 198147,
	"CONMEBOL - U20 Championship" : 4679,
	"CONMEBOL - Copa America Qualifiers" : 192496,
	"FIFA - World Cup Qualifiers South America" : 2016,
	"South America - South American Womens Games" : 201675,
	"CONMEBOL - U20 Championship Women" : 2473,
	"CONMEBOL - Copa Libertadores" : 1875,
	"CONMEBOL - Copa Sudamericana" : 2472,
	"CONMEBOL - Pre-Olympic Tournament U23" : 207687,
	"CONMEBOL - Copa America Femenina Corners" : 220700,
	"CONMEBOL - Copa Libertadores U20" : 192708,
},

"China" : 
{
	"China - League One Corners" : 226755,
	"China - League One" : 8655,
	"China - Super Cup Corners" : 198639,
	"China - FA Cup" : 1859,
	"China - Super League" : 6417,
	"China - League Two" : 213349,
	"China - Super Cup" : 10813,
	"China - FA Cup Corners" : 210037,
	"China - Super League Women" : 224723,
	"China - Super League Corners" : 11670,
},

"Ethiopia" : 
{
	"Ethiopia - Premier League" : 211244,
	"Ethiopia - Premier League Women" : 236215,
},

"Romania" : 
{
	"Romania - Cup Women" : 212604,
	"Romania - Liga 1 Corners" : 16340,
	"Romania - Liga 2" : 199710,
	"Romania - Cup Corners" : 6838,
	"Romania - Super Cup" : 187758,
	"Romania - Cup" : 2396,
	"Romania - U19 Cup" : 219005,
	"Romania - Liga 1 Women" : 217134,
	"Romania - U19" : 210259,
	"Romania - Superliga Women" : 199941,
	"Romania - Super Cup Corners" : 199490,
	"Romania - Liga 1" : 2395,
	"Romania - Liga 2 Women" : 217317,
},

"Canada" : 
{
	"Canada - Soccer League Corners" : 199543,
	"Canada - Championship" : 1850,
	"Canada - Premier League" : 205098,
	"Canada - Soccer League" : 1851,
	"Canada - PLSQ" : 205437,
},

"Israel" : 
{
	"Israel - Liga ha'Al" : 212975,
	"Israel - U19 Elite Division" : 192533,
	"Israel - State Cup Corners" : 200632,
	"Israel - Liga Alef" : 10604,
	"Israel - Ligat Leumit" : 2133,
	"Israel - Liga Bet" : 198331,
	"Israel - State Cup Women" : 200361,
	"Israel - Ligat Al Toto Cup" : 2138,
	"Israel - Premier League Women" : 192782,
	"Israel - Super Cup Corners" : 209616,
	"Israel - Ligat Leumit Toto Cup" : 197578,
	"Israel - Liga ha'Al Corners" : 212977,
	"Israel - U19 Cup" : 198500,
	"Israel - Premier League Corners" : 6650,
	"Israel - Ligat Leumit Corners" : 198074,
	"Israel - Premier League" : 2136,
	"Israel - Ligat Al Toto Cup Corners" : 198186,
	"Israel - Super Cup" : 191425,
	"Israel - State Cup" : 2129,
	"Israel - Liga Leumit U19" : 218098,
},

"Switzerland" : 
{
	"Switzerland - Nationalliga B Women" : 224679,
	"Switzerland - Cup" : 2519,
	"Switzerland - Erste Liga Cup" : 230393,
	"Switzerland - Super League Women" : 210756,
	"Switzerland - 1. Liga Classic" : 201159,
	"Switzerland - Challenge League" : 2518,
	"Switzerland - 1. Liga Cup" : 224956,
	"Switzerland - Promotion League" : 219077,
	"Switzerland - U19 Elite" : 227679,
	"Switzerland - Cup Corners" : 187569,
	"Switzerland - Cup Women" : 213561,
	"Switzerland - Challenge League Corners" : 192764,
	"Switzerland - Super League" : 2517,
	"Switzerland - Super League Corners" : 6428,
},

"CAF" : 
{
	"CAFA - Nations Cup Corners" : 226472,
	"CAF - Super Cup Corners 1" : 198595,
	"CAF - Confederation Cup Corners" : 199461,
	"CAF - Super Cup 2" : 10897,
	"CAF - Africa Cup of Nations U20 Corners" : 224645,
	"CAF - Champions League Corners" : 198591,
	"CAF - Africa Cup of Nations Corners" : 10576,
	"CAF - African Nations Championship Corners" : 192619,
	"CAF - Africa Cup of Nations Qualifiers Corners" : 199372,
},

"South Africa" : 
{
	"South Africa - Cup" : 2411,
	"South Africa - Cosafa U20 Cup" : 198158,
	"South Africa - Diski Challenge U23" : 211123,
	"South Africa - Cup Corners" : 210007,
	"South Africa - League Cup" : 230369,
	"South Africa - Premier League Corners" : 192773,
	"South Africa - 8 Cup" : 191388,
	"South Africa - PSL Corners" : 196765,
	"South Africa - 1st Division" : 212479,
	"South Africa - PSL" : 196763,
},

"Nepal" : 
{
	"Nepal - B Division" : 218800,
	"Nepal - C Division" : 219525,
	"Nepal - A Division" : 217495,
},

"Russian Federation" : 
{
	"Russia - Supreme Division Women" : 196776,
	"Russia - First League Corners" : 198010,
	"Russia - Women Cup" : 202134,
	"Russia - Super Cup" : 4763,
	"Russia - Super Cup Corners" : 197302,
	"Russia - FNL 2" : 9757,
	"Russia - Premier League Corners" : 6431,
	"Russia - Cup Corners" : 218793,
	"Russia - Youth Championship U21 Corners" : 197994,
	"Russia - 3rd Division" : 201329,
	"Russia - First League" : 35174,
	"Russia - Premier League" : 2406,
	"Russia - Youth Championship U19" : 9429,
	"Russia - Cup" : 2409,
},

"Georgia" : 
{
	"Georgia - Super Cup" : 212164,
	"Georgia - Erovnuli Liga" : 10236,
	"Georgia - Cup" : 2044,
	"Georgia - Erovnuli Liga 2" : 201857,
	"Georgia - Liga 3" : 207288,
},

"Vietnam" : 
{
	"Vietnam - Cup Corners" : 198253,
	"Vietnam - Super Cup" : 211452,
	"Vietnam - Womens National League" : 197600,
	"Vietnam - V League 2" : 201256,
	"Vietnam - U19 Womens Championship" : 212599,
	"Vietnam - V League" : 9154,
	"Vietnam - U21 Championship" : 202146,
	"Vietnam - V League Corners" : 198300,
	"Vietnam - 2nd Division" : 201499,
	"Vietnam - Womens National Cup" : 205225,
	"Vietnam - Cup" : 9253,
	"Vietnam - U19 Championship" : 203872,
},

"CONMEBOL" : 
{
	"CONMEBOL - Copa America Bookings" : 187543,
	"CONMEBOL - Copa Libertadores Bookings" : 227498,
	"CONMEBOL - Copa Sudamericana  Bookings" : 227512,
	"CONMEBOL - Recopa Sudamericana Corners" : 197505,
	"CONMEBOL - Copa America Corners" : 187542,
	"CONMEBOL - Copa Libertadores Corners" : 6283,
	"CONMEBOL - Copa Sudamericana Corners" : 6914,
	"CONMEBOL - Copa Libertadores Femenina Corners" : 198148,
	"CONMEBOL - U20 Championship Corners" : 198409,
},

"Jamaica" : 
{
	"Jamaica - Premier League Corners" : 200774,
	"Jamaica - Cup" : 225944,
	"Jamaica - Premier League" : 10407,
},

"Lithuania" : 
{
	"Lithuania - National Basketball League" : 208617,
	"Lithuania - A Lyga Women" : 209891,
	"Lithuania -  A Lyga Corners" : 199033,
	"Lithuania -  A Lyga" : 2211,
	"Lithuania - Cup" : 10150,
	"Lithuania -  1 Lyga" : 201890,
	"Lithuania - Super Cup" : 212788,
},

"Africa" : 
{
	"UNAF - U20 Tournament" : 222830,
	"CAF - Africa Cup of Nations" : 1718,
	"CAF - Champions League Women" : 217018,
	"CAF - Africa Cup of Nations Bookings" : 205522,
	"CAF - Champions League Qualifiers" : 200751,
	"CAF - Super Cup" : 208188,
	"COSAFA - U20 Championship" : 203600,
	"CAF - Confederation Cup" : 187709,
	"Africa - Cup of Nations Women" : 220652,
	"COSAFA - U20 Cup Women" : 206155,
	"WAFU - Cup Corners" : 206708,
	"African Games U20" : 234464,
	"CAF - Africa Cup of Nations Qualifiers" : 1713,
	"CAF - U20 Championship" : 11686,
	"COSAFA - Cup" : 197076,
	"Africa - Cup of Nations" : 218006,
	"COSAFA - Cup Women" : 202528,
	"CECAFA - U20 Championship" : 210959,
	"CAF - Africa Cup of Nations U20" : 204179,
	"CAF - Super Cup Corners" : 208190,
	"CAF - African Football League" : 230376,
	"CAF - All Africa Games U23" : 206479,
	"CAF - Africa Cup of Nations U23" : 192351,
	"COSAFA - Cup Corners" : 201693,
	"FIFA - World Cup Qualifiers Africa" : 2013,
	"CAF - African Nations Championship Qualifiers" : 187665,
	"African Games U20 Women" : 234488,
	"CECAFA - Club Cup" : 201947,
	"Africa - Cup of Nations Women Corners" : 221027,
	"CAF - Africa Cup of Nations U23 Qualifiers" : 204527,
	"CAF - African Nations Championship" : 1717,
	"CAF - Confederation Cup Qualifiers" : 200752,
	"CAF - Africa Women Cup of Nations Qualifiers" : 216622,
	"CAF - Olympic Qualifiers Women" : 226857,
	"COSAFA - Champions League Women" : 227684,
	"CAF - Africa Women Cup of Nations" : 198017,
	"CAF - Champions League" : 1715,
},

"Finland" : 
{
	"Finland - Ykkosliiga" : 2025,
	"Finland - Cup Women" : 2023,
	"Finland - League Cup Corners" : 192724,
	"Finland - Cup Corners" : 197053,
	"Finland - Kolmonen" : 201512,
	"Finland - Ykkosliiga Corners" : 196769,
	"Finland - Veikkausliiga" : 2024,
	"Finland - Kakkosen Cup" : 203922,
	"Finland - Kakkonen Group A" : 228086,
	"Finland - Kakkonen Group C" : 228088,
	"Finland - U20 League" : 197320,
	"Finland - Veikkausliiga Corners" : 6385,
	"Finland - Kakkonen Group B Corners" : 228090,
	"Finland - League Cup" : 4993,
	"Finland - Kansallinen Women" : 197235,
	"Finland - Kakkonen Corners" : 201673,
	"Finland - Cup" : 2020,
	"Finland - Kakkonen Group B" : 228087,
	"Finland - Ykkonen" : 234884,
	"Finland - Kakkonen" : 2018,
	"Finland - Kakkonen Group C Corners" : 228091,
	"Finland - Ykkonen Corners" : 234885,
	"Finland - Ykkoscup" : 218491,
	"Finland - Ykkonen Women" : 201503,
	"Finland - Kakkonen Group A Corners" : 228089,
},

"Argentina" : 
{
	"Argentina - Cup" : 1741,
	"Argentina - Torneo Federal A" : 202608,
	"Argentina - Reserve Superliga Cup" : 204882,
	"Argentina - Trofeo des Campeones Corners" : 223048,
	"Argentina - Primera C Metropolitana" : 201151,
	"Argentina - Regional League" : 222090,
	"Argentina - Liga Pro Reserves" : 226450,
	"Argentina - Liga Pro Corners" : 210705,
	"Argentina - Women Regional League" : 216587,
	"Argentina - Primera B Women" : 217863,
	"Argentina - Primera C Women" : 223428,
	"Argentina - Regional Cup" : 219063,
	"Argentina - Primera B Metropolitana" : 201149,
	"Argentina - Reserve League" : 200786,
	"Argentina - Youth League U20" : 214748,
	"Argentina - Primera C Metropolitana Corners" : 206655,
	"Argentina - Promotion Playoffs" : 233586,
	"Argentina - Primera Division Women" : 208258,
	"Argentina - Superliga Champions Trophy" : 207391,
	"Argentina - Torneo Promocional Amateur" : 234301,
	"Argentina - Trofeo des Campeones" : 223046,
	"Argentina - Primera D Metropolitana" : 201153,
	"Argentina - Primera Division Corners" : 6327,
	"Argentina - Super Cup" : 192769,
	"Argentina - Super Cup Corners" : 198502,
	"Argentina - Liga Pro" : 210697,
	"Argentina - Torneo Regional Federal Amateur" : 204186,
	"Argentina - Cup Women" : 223273,
	"Argentina - Primera D Metropolitana Corners" : 206657,
	"Argentina - Cup Corners" : 196767,
	"Argentina - Copa Santa Fe" : 201979,
	"Argentina - Copa de la Liga Profesional" : 204784,
	"Argentina - Primera B Nacional" : 1739,
	"Argentina - Copa de la Liga Profesional Corners" : 204785,
	"Argentina - Copa Mendoza" : 223049,
	"Argentina - Primera B Metropolitana Corners" : 206653,
	"Argentina - Primera B Nacional Corners" : 6820,
	"Argentina - Primera Division" : 1740,
	"Argentina - Torneos De Verano" : 224041,
},

"AFC" : 
{
	"AFC - Asian Cup Bookings" : 203795,
	"AFC - Asian Cup Women Corners" : 198965,
	"AFC - U23 Cup Qualifiers Corners" : 204531,
	"AFC - Champions League Qualifiers Corners" : 192714,
	"AFC - Asian Cup Qualifiers Corners" : 198950,
	"Asian Games U23" : 227790,
	"AFC - Asian Cup Corners" : 10516,
	"AFC - Champions League Corners" : 9596,
	"AFC - U23 Cup Corners" : 200506,
	"AFC - U20 Cup Corners" : 224632,
	"AFC - Club Championship Women" : 230606,
	"England - Northern Premier League Corners" : 199647,
	"Asian Games - Women" : 227792,
},

"Denmark" : 
{
	"Denmark - Division 2 Women" : 215029,
	"Denmark - Superliga Corners" : 6426,
	"Denmark - Superliga" : 1913,
	"Denmark - U19 Corners" : 198121,
	"Denmark - Womens Cup" : 201377,
	"Denmark - Cup" : 1908,
	"Denmark - Cup Corners" : 216599,
	"Denmark - Division 1 Corners" : 6666,
	"Denmark - U19 League" : 163789,
	"Denmark - Division 1" : 1904,
	"Denmark - U21 League" : 1924,
	"Denmark - Division 1 Women" : 209838,
	"Denmark - 2nd Division" : 191393,
	"Denmark - Elitedivisionen Women" : 187661,
	"Denmark - Reserve League" : 10841,
	"Denmark - Future Cup U21" : 221698,
	"Denmark - 3rd Division" : 214819,
	"Denmark - Denmark Series" : 201505,
	"Denmark - Reserve League Corners" : 198031,
},

"CONCACAF" : 
{
	"CONCACAF - Champions Cup Corners" : 194553,
	"CONCACAF - Gold Cup Corners" : 6401,
	"CONCACAF - Central American Cup" : 227146,
	"CONCACAF - Gold Cup Qualifiers Women" : 227942,
	"CONCACAF - U20 Championship Corners" : 198580,
	"CONCACAF - U20 Championship Qualifiers" : 234264,
	"CONCACAF - Gold Cup Qualifiers Corners" : 226461,
	"CONCACAF - Gold Cup Women" : 234262,
	"CONCACAF - U20 Championship Women Corners" : 200627,
	"CONCACAF - Caribbean Club Shield" : 227282,
	"CONCACAF - N/C America Womens WC Qualification Corners" : 220668,
	"CONCACAF - Championship Women Corners" : 220670,
	"CONCACAF - League Corners" : 199748,
},

"United Arab Emirates" : 
{
	"UAE - U21 League" : 10750,
	"UAE - Youth League" : 211304,
	"UAE - Reserve League" : 210983,
	"United Arab Emirates - FA Cup" : 10072,
	"UAE - U19 League" : 217344,
	"UAE - Division 2" : 2626,
	"UAE - League Cup Corners" : 225856,
	"United Arab Emirates - League Cup Corners" : 207228,
	"UAE - Super Cup" : 218134,
	"UAE - Cup" : 2624,
	"United Arab Emirates - FA Cup Corners" : 204900,
	"UAE - Pro League" : 8126,
	"UAE - Cup Corners" : 224701,
	"UAE - Division 1" : 2625,
	"UAE - Pro League Corners" : 16276,
	"UAE - League Cup" : 10034,
},

"Germany" : 
{
	"Germany - Regional Cup Westfalen" : 149053,
	"Germany - Oberliga Westfalen" : 197471,
	"Germany - Oberliga Mitterlrhein" : 197785,
	"Germany - Bundesliga 2 Corners" : 5886,
	"Germany - Regional Cup Thuringen" : 213778,
	"Germany - Oberliga Bayern Nord Corners" : 192149,
	"Germany - Oberliga Baden-Wurttemberg" : 2073,
	"Germany - Regionalliga Bavaria" : 6546,
	"Germany - Bundesliga U19 West" : 217395,
	"Germany - Cup" : 2067,
	"Germany - Brandenburg Cup" : 8719,
	"Germany - Oberliga Nordost Nord" : 191448,
	"Germany - Regional Cup Niederrhein" : 8721,
	"Germany - Regional Cup Rheinland" : 8722,
	"Germany - Regional Cup Hamburg" : 187892,
	"Germany - Regional Cup Wurttemberg" : 219836,
	"Germany - Verbandsliga" : 219329,
	"Germany - Regional Cup Bayern" : 215226,
	"Germany - Regionalliga North Corners" : 192396,
	"Germany - Bundesliga U19" : 8705,
	"Germany - Regional Cup Mittelrhein" : 8732,
	"Germany - Regionalliga North" : 2048,
	"Germany - Super Cup Corners" : 6441,
	"Germany - Oberliga Playoffs" : 220135,
	"Germany - Regionalliga Sued" : 2049,
	"Germany - Regional Cup Berlin" : 199909,
	"Germany - Regionalliga West" : 2050,
	"Germany - Regional Cup Bremen" : 213765,
	"Germany - Bundesliga U19 Cup" : 194704,
	"Germany - Regionalliga South West Corners" : 194585,
	"Germany - Bundesliga Women" : 1845,
	"Germany - Oberliga Bayern" : 2072,
	"Germany - Oberliga Schleswig-Holstein" : 191451,
	"Germany - Saarlandliga" : 221236,
	"Germany - Bundesliga 2" : 1843,
	"Germany - Regional Cup Schleswig-Holstein" : 197265,
	"Germany - Oberliga Bayern Nord" : 2065,
	"Germany - Regionalliga West Corners" : 191364,
	"Germany - Bundesliga 3 Corners" : 8564,
	"Germany - DFB Pokal Women" : 2068,
	"Germany - Westfalenliga" : 219332,
	"Germany - Regionalliga North East Corners" : 194782,
	"Germany - Bundesliga" : 1842,
	"Germany - Regional Cup Hessen" : 216413,
	"Germany - Bayern Ligapokal" : 210492,
	"Germany - Regionalliga Bavaria Corners" : 6680,
	"Germany - Westphalia DFB Cup" : 205220,
	"Germany - Oberliga Nordost Sud" : 191449,
	"Germany - Bundesliga 2 Women" : 200814,
	"Germany - Regional Cup Niedersachsen" : 213041,
	"Germany - Oberliga Niederrhein" : 197470,
	"Germany - Oberliga Hessen" : 191447,
	"Germany - Bundesliga Bookings" : 197439,
	"Germany - Bundesliga U19 Sud/Sudwest" : 217394,
	"Germany - Oberliga Rheinland-Pfalz/Saar" : 191450,
	"Germany - Regionalliga Playoff Corners" : 196929,
	"Germany - Regional Cup Sachsen" : 216349,
	"Germany - Berlin Liga" : 215913,
	"Germany - Regional Cup Südbaden" : 209927,
	"Germany - Oberliga Bayern Sud" : 2066,
	"Germany - Landesliga" : 220162,
	"Germany - Bundesliga 3" : 1844,
	"Germany - Oberliga Niedersachsen" : 191454,
	"Germany - Bundesliga U19 Nord/Nordost" : 217393,
	"Germany - Regionalliga Women" : 236138,
	"Germany - Cup Bookings" : 196869,
	"Germany - State Leagues" : 216381,
	"Germany - Bundesliga U19 Corners" : 198012,
	"Germany - Bundesliga Corners" : 5874,
	"Germany - Oberliga Hamburg" : 191453,
	"Germany - Oberliga Bremen" : 191452,
	"Germany - Regional Cup Saarland" : 219833,
	"Germany - Regionalliga North East" : 6545,
	"Germany - Super Cup Bookings" : 199589,
	"Germany - Super Cup" : 2054,
	"Germany - Regionalliga Playoff" : 196875,
	"Germany - Regional Cup South West" : 217610,
	"Germany - Regionalliga South West" : 6543,
	"Germany - Regional Cup Baden" : 216128,
	"Germany - Bundesliga 2 Bookings" : 209023,
	"Germany - Cup Corners" : 6325,
},

"New Zealand" : 
{
	"New Zealand - Cup Women" : 226441,
	"New Zealand - Premier League Corners" : 207226,
	"New Zealand - National Womens League" : 202828,
	"New Zealand - Southern League" : 201656,
	"New Zealand - Regional Leagues" : 202444,
	"New Zealand - Northern League" : 201658,
	"New Zealand - Central League" : 201654,
	"New Zealand - Chatham Cup" : 201901,
	"New Zealand - Mainland Premier League" : 201710,
	"New Zealand - Dunedin Premier League" : 201708,
	"New Zealand - National League" : 2264,
	"New Zealand - Youth League" : 202830,
},

"Americas" : 
{
	"Pan American Games - Men U23" : 2354,
	"Puerto Rico - League Women" : 223195,
	"Pan American Games - Women" : 2355,
	"Puerto Rico - National League" : 223358,
},

"Rwanda" : 
{
	"Rwanda - Cup" : 219222,
	"Rwanda - Premier League" : 211116,
},

"Azerbaijan" : 
{
	"Azerbaijan - Cup" : 1796,
	"Azerbaijan - Premier League" : 7167,
	"Azerbaijan - Division 1" : 201234,
	"Azerbaijan - Premier League Corners" : 198489,
	"Azerbaijan - Reserve League" : 227317,
},

"Czech Republic" : 
{
	"Czech Republic - Czech Liga Corners" : 6758,
	"Czech Republic - FNL" : 9441,
	"Czech Republic - Women Cup" : 223336,
	"Czech Republic - U19 League" : 10895,
	"Czech Republic - Cup Corners" : 194587,
	"Czech Republic - 3. Liga CFL" : 228205,
	"Czech Republic - FNL Corners" : 198056,
	"Czech Republic - Tipsport Liga" : 207586,
	"Czech Republic - 1. Liga Women" : 208267,
	"Czech Republic - 3. Liga MSFL" : 228206,
	"Czech Republic - Cup" : 1898,
	"Czech Republic - 4. Liga" : 214726,
	"Czech Republic - U21 League" : 9755,
	"Czech Republic - 2. Liga Corners" : 207225,
	"Czech Republic - Czech Liga" : 1891,
	"Czech Republic - U21 League Corners" : 197996,
	"Czech Republic - 2. Liga Women" : 222328,
},

"Bangladesh" : 
{
	"Bangladesh - Federation Cup" : 199229,
	"Bangladesh - Premier League" : 88184,
	"Bangladesh - Premier League Corners" : 198029,
	"Bangladesh - Championship" : 211889,
	"Bangladesh - Independence Cup" : 217656,
},

"Albania" : 
{
	"Albania - 1st Division" : 212294,
	"Albania - Cup" : 209203,
	"Albania - 2nd Division" : 212560,
	"Albania - Super Cup" : 223552,
	"Albania - Superliga" : 1722,
},

"Slovakia" : 
{
	"Slovakia - Cup Women" : 210117,
	"Slovakia - Cup Corners" : 201313,
	"Slovakia - Super Liga Corners" : 196725,
	"Slovakia - Super Liga" : 2453,
	"Slovakia - Liga I Women" : 202382,
	"Slovakia - 3. Liga" : 210303,
	"Slovakia - U19 League" : 199687,
	"Slovakia - 2. Liga" : 201139,
	"Slovakia - Cup" : 2454,
	"Slovakia - 4. Liga" : 221688,
},

"Peru" : 
{
	"Peru - Copa Bicentenario" : 205707,
	"Peru - Campeonato Nacional Women" : 226953,
	"Peru - Copa Inca" : 10899,
	"Peru - Liga 2" : 201986,
	"Peru - Liga 1" : 2366,
	"Peru - Liga 1 Corners" : 192394,
	"Peru - Super Cup" : 207704,
	"Peru - Reserve League" : 220698,
	"Peru - Copa Peru" : 5592,
},

"Belarus" : 
{
	"Belarus - Cup Corners" : 201311,
	"Belarus - Womens Cup" : 213435,
	"Belarus - Womens Super Cup" : 204578,
	"Belarus - Premier League" : 6416,
	"Belarus - Reserve League" : 208749,
	"Belarus - Super Cup Corners" : 204394,
	"Belarus - Super Cup" : 204392,
	"Belarus - 1st Division Corners" : 208962,
	"Belarus - Premier League Corners" : 199736,
	"Belarus - 2nd Division" : 209061,
	"Belarus - Women Premier League" : 197045,
	"Belarus - 1st Division" : 201855,
	"Belarus - Cup" : 1813,
},

"Mexico" : 
{
	"Mexico - Cup Corners" : 197933,
	"Mexico - Liga MX Women Corners" : 226960,
	"Mexico - Primera Division Corners" : 6423,
	"Mexico - Super Cup Corners" : 220390,
	"Mexico - Liga Premier" : 207004,
	"Mexico - Copa Conecta" : 217797,
	"Mexico - Segunda Division Corners" : 198487,
	"Mexico - Super Cup" : 202034,
	"Mexico - Ascenso Corners" : 198064,
	"Mexico - Primera Division" : 2242,
	"Mexico - Liga TDP" : 217562,
	"Mexico - Cup" : 5778,
	"Mexico - Champion of Champions" : 205749,
	"Mexico - Segunda Division" : 197534,
	"Mexico - Ascenso" : 191423,
	"Mexico - Liga Premier Serie B" : 207005,
	"Mexico - Liga MX Women" : 201165,
	"Mexico - Liga de Expansión MX Corners" : 209773,
	"Mexico - U20 League Corners" : 192107,
	"Mexico - Liga de Expansión MX" : 209758,
	"Mexico - U20 League" : 10602,
	"Mexico - U23 League" : 226745,
},

"Saudi Arabia" : 
{
	"Saudi Arabia - Kings Cup" : 198379,
	"Saudi Arabia - U19 League" : 210365,
	"Saudi Arabia - Pro League Corners" : 16278,
	"Saudi Arabia - Super Cup" : 218128,
	"Saudi Arabia - Division 2" : 211248,
	"Saudi Arabia - Kings Cup Corners" : 198380,
	"Saudi Arabia - Pro League" : 10419,
	"Saudi Arabia - Reserve League" : 230502,
	"Saudi Arabia - Crown Prince Cup" : 10791,
	"Saudi Arabia - Super Cup Corners" : 224111,
	"International - Pan Arab Games U23" : 226733,
	"Saudi Arabia - Champions Cup" : 10792,
	"Saudi Arabia - Division 1" : 10600,
},

"Ghana" : 
{
	"Ghana - Premier League Corners" : 201325,
	"Ghana - FA Cup" : 213517,
	"Ghana - Premier League" : 196927,
	"Ghana - Super Cup" : 227566,
},

"Nigeria" : 
{
	"Nigeria - NPFL" : 199487,
	"Nigeria - Cup" : 235788,
},

"Singapore" : 
{
	"Singapore - NFL Division 1" : 220654,
	"Singapore - S League Corners" : 9603,
	"Singapore - Premier League" : 210554,
	"Singapore - Community Shield" : 204284,
	"Singapore - S League" : 9427,
	"Singapore - Cup Corners" : 202125,
	"Singapore - Cup" : 9945,
},

"Armenia" : 
{
	"Armenia - Super Cup" : 209579,
	"Armenia - Premier League" : 1742,
	"Armenia - Cup" : 191700,
	"Armenia - 1st League" : 201171,
},

"Djibouti" : 
{
	"Djibouti - Division 1" : 212780,
},

"Faroe Islands" : 
{
	"Faroe Islands - Meistaradeildin" : 201861,
	"Faroe Islands - 1. Deild" : 209095,
	"Faroe Islands - Cup" : 2004,
	"Faroe Islands - Premier League Women" : 209893,
	"Faroe Islands - Premier League" : 201777,
	"Faroe Islands - Super Cup Women" : 234781,
},

"Panama" : 
{
	"Panama - Liga Prom" : 212346,
	"Panama - Primera Division Corners" : 199521,
	"Panama - Cup" : 191914,
	"Panama - Primera Division" : 10573,
	"Panama - Liga de Futbol Women" : 219888,
},

"France" : 
{
	"France - National 2" : 200815,
	"France - Super Cup Corners" : 6489,
	"France - Cup Bookings" : 208164,
	"France - U19 Cup" : 201141,
	"France - League Cup Corners" : 6836,
	"France - Cup" : 2032,
	"France - League Cup" : 2034,
	"France - Ligue 1 Bookings" : 204807,
	"France - Cup Women" : 199273,
	"France - U19 League" : 197590,
	"France - Cup Corners" : 6321,
	"France - League Cup Bookings" : 207686,
	"France - Super Cup Bookings" : 206140,
	"France - Ligue 1" : 2036,
	"France - Ligue 2" : 2037,
	"France - Ligue 2 Corners" : 6495,
	"France - Ligue 1 Corners" : 6267,
	"France - Feminine Division 2" : 215545,
	"France - National Corners" : 192419,
	"France - National" : 2027,
	"France - Feminine Division 1" : 2033,
	"France - Super Cup" : 2035,
	"France - National 3" : 215521,
},

"FIFA World Cup 2018" : 
{
	"FIFA - World Cup Bookings" : 201691,
	"FIFA - World Cup Corners" : 8581,
},

"Botswana" : 
{
	"Botswana - Premier League" : 218775,
},

"Iran" : 
{
	"Iran - 2nd Division" : 218169,
	"Iran - Azadegan League" : 209653,
	"Iran - U23 League" : 211384,
	"Iran - Pro League" : 2118,
	"Iran - Cup" : 10346,
},

"Japan" : 
{
	"Japan - Women Empowerment League" : 215919,
	"Japan - University Championship Women" : 223691,
	"Japan - League Cup" : 4995,
	"Japan - J3 League" : 10078,
	"Japan - J League Corners" : 6308,
	"Japan - League Cup Women" : 2161,
	"Japan - Regional Cup" : 235501,
	"Japan - Super Cup Corners" : 192844,
	"Japan - Cup Women" : 211191,
	"Japan - Super Cup" : 5421,
	"Japan - Nadeshiko Division 1 Women" : 209517,
	"Japan - University Championship" : 223571,
	"Japan - J2 League" : 2159,
	"Japan - Cup Corners" : 9747,
	"Japan - Cup" : 2160,
	"Japan - Football League" : 201838,
	"Japan - Regional League" : 203462,
	"Japan - League Cup Corners" : 6595,
	"Japan - J League" : 2157,
	"Japan - Nadeshiko Division 2 Women" : 209509,
	"Japan - Nadeshiko League Cup" : 205711,
	"Japan - J2 League Corners" : 6784,
	"Japan - J3 League Corners" : 220544,
},

"Paraguay" : 
{
	"Paraguay - Cup Corners" : 203444,
	"Paraguay - Division Intermedia Corners" : 220666,
	"Paraguay - Division Profesional" : 2359,
	"Paraguay - Super Cup Corners" : 224031,
	"Paraguay - Cup" : 202152,
	"Paraguay - Division Intermedia" : 201859,
	"Paraguay - Women League" : 226950,
	"Paraguay - Reserve League" : 202503,
	"Paraguay - Division Profesional Corners" : 9591,
	"Paraguay - Super Cup" : 224028,
},

"Olympics" : 
{
	"Olympic - Men U23 Corners" : 197371,
	"Olympic - Qualifiers Women" : 2350,
	"Olympic - Women" : 5000,
	"Olympic - Men U23 Bookings" : 214376,
	"Olympic - Women Bookings" : 214373,
	"Olympic - Women Corners" : 197368,
	"Olympic - Men U23" : 197231,
},

"Cameroon" : 
{
	"Cameroon - Elite One" : 1849,
	"Cameroon - Cup" : 199745,
	"Cameroon - Elite Two" : 201157,
	"Cameroon - Championship Women" : 211230,
},

"Wales" : 
{
	"Wales - Premier League" : 2678,
	"Wales - Premier League Corners" : 198171,
	"Wales - Premier Womens League" : 215641,
	"Wales - League Cup" : 10285,
	"Wales - Cup" : 2679,
	"Wales - Championship" : 214556,
},

"Kenya" : 
{
	"Kenya - Super League" : 201475,
	"Kenya - Shield Cup" : 199972,
	"Kenya - Premier League" : 187707,
	"Kenya - Super Cup" : 198688,
},

"Fiji" : 
{
	"Fiji - National Football League" : 203918,
	"Fiji - FA Cup" : 204942,
},

"South Korea" : 
{
	"Korea Republic - K3 League Corners" : 210039,
	"Korea Republic - K League 1 Corners" : 207559,
	"Korea Republic - K League Women" : 197223,
	"Korea Republic - FA Cup" : 2181,
	"Korea Republic - K League 2 Corners" : 207560,
	"Korea Republic - FA Cup Corners" : 214836,
	"Korea Republic - K3 League" : 207553,
	"Korea Republic - K League 2" : 207552,
	"Korea Republic - K4 League" : 207554,
	"Korea Republic - K League 1" : 207551,
},

"Kyrgyzstan" : 
{
	"Kyrgyzstan - Premier League" : 212466,
	"Kosovo - Cup" : 211235,
},

"Tajikistan" : 
{
	"Tajikistan - Super Cup" : 208855,
	"Tajikistan - Higher League" : 208861,
	"Tajikistan - National Football League" : 202529,
},

"Qatar" : 
{
	"Qatar - Stars League" : 8128,
	"Qatar - Stars Cup Corners" : 203309,
	"Qatar - Reserve League" : 216125,
	"Qatar - Emir Cup" : 10903,
	"Qatar - QFA Cup" : 212958,
	"Qatar - Cup" : 10905,
	"Qatar - U23 League" : 210548,
	"Qatar - Super Cup" : 10907,
	"Qatar - 2nd Division Cup" : 217445,
	"Qatar - Emir Cup Corners" : 201439,
	"Qatar - Cup Corners" : 225162,
	"Qatar - U21 League" : 233577,
	"Qatar - Stars League Corners" : 11711,
	"Qatar - U23" : 210547,
	"Qatar - Sheikh Jassim Cup" : 206318,
	"Qatar - Stars Cup" : 10901,
	"Qatar - 2nd Division" : 202606,
},

"FIFA" : 
{
	"FIFA - World Cup Qualifiers Europe Women Corners" : 6852,
	"FIFA - World Cup U20 Corners" : 6381,
	"FIFA - World Cup Qualifiers Intercontinental Corners" : 7016,
	"FIFA - Arab Cup Corners" : 217580,
	"FIFA - World Cup Qualifiers Africa Corners" : 6990,
	"FIFA - Club World Cup Bookings" : 218614,
	"FIFA - World Cup U17 Corners" : 6779,
	"FIFA - World Cup Qualifiers North America Corners" : 192271,
	"FIFA - World Cup Qualifiers Europe Bookings" : 200110,
	"FIFA - World Cup Qualifiers South America Corners" : 6338,
	"FIFA - Club World Cup Corners" : 10423,
	"FIFA - World Cup U20 Bookings" : 205247,
	"FIFA - World Cup Qualifiers Oceania Corners" : 198927,
	"FIFA - U20 World Cup Women Corners" : 197971,
	"FIFA - World Cup Qualifiers Asia Corners" : 6331,
	"FIFA - World Cup Qualifiers Europe Corners" : 5894,
	"FIFA - World Cup Qualifiers South America Bookings" : 210842,
},

"Colombia" : 
{
	"Colombia - Liga Women" : 201441,
	"Colombia - Super Cup" : 10629,
	"Colombia - Cup Corners" : 199500,
	"Colombia - Cup" : 1867,
	"Colombia - Primera C" : 215036,
	"Colombia - Superliga Corners" : 216291,
	"Colombia - Primera A Corners" : 72425,
	"Colombia - Primera B" : 10921,
	"Colombia - U19 Championship" : 220089,
	"Colombia - Primera A" : 5591,
	"Colombia - Superliga" : 209948,
	"Colombia - Regional League" : 219053,
	"Colombia - Primera B Corners" : 200797,
},

"Slovenia" : 
{
	"Slovenia - U19 League" : 209925,
	"Slovenia - Cup" : 2456,
	"Slovenia - Prva Liga Corners" : 194780,
	"Slovenia - 3. SNL" : 213328,
	"Slovenia - Prva Liga" : 2457,
	"Slovenia - 2. SNL" : 201109,
	"Slovenia - Cup Corners" : 201169,
},

"Kazakhstan" : 
{
	"Kazakhstan - Cup" : 2176,
	"Kazakhstan - Super Cup" : 10967,
	"Kazakhstan - Premier League" : 6418,
	"Kazakhstan - Premier League Corners" : 201532,
},

"Thailand" : 
{
	"Thailand - League 1" : 6419,
	"Thailand - League 3" : 210377,
	"Thailand - League 1 Women" : 210832,
	"Thailand - League 2" : 200748,
	"International - Kings Cup Corners" : 205273,
	"Thailand - League 1 Corners" : 198578,
	"International - Kings Cup" : 2178,
	"Thailand - University League" : 226524,
	"Thailand - League Cup" : 9096,
	"Thailand - Champions Cup" : 221321,
	"Thailand - FA Cup" : 6420,
},

"Tanzania" : 
{
	"Tanzania - Premier League" : 210948,
	"Tanzania - Liga Kuu Bara" : 210946,
	"Zanzibar - Mapinduzi Cup" : 218153,
	"Tanzania - Cup" : 218625,
},

"Malaysia" : 
{
	"Malaysia - Liga M3" : 219111,
	"Malaysia - U19 Cup" : 219112,
	"Malaysia - FA Cup" : 198556,
	"Malaysia - Challenge Cup Corners" : 206306,
	"Malaysia - President Cup U21" : 221209,
	"Malaysia - Premier League" : 2233,
	"Malaysia - Cup" : 2232,
	"Malaysia - Super League Corners" : 198392,
	"Malaysia - MFL Cup U23" : 224780,
	"Malaysia - President Cup U20" : 236753,
	"Malaysia - Challenge Cup" : 206305,
	"Malaysia - Premier League Corners" : 198480,
	"Malaysia - Super League" : 2234,
	"Malaysia - University League" : 223743,
},

"Bahrain" : 
{
	"Bahrain - Premier League Corners" : 192105,
	"Bahrain - Premier League" : 1797,
	"Bahrain - Super Cup Corners" : 202582,
	"Bahrain - Super Cup" : 202581,
	"Bahrain - 2nd Division" : 201167,
	"Bahrain - Kings Cup" : 1800,
	"Bahrain - FA Cup" : 1798,
	"Bahrain - Federation Cup" : 212497,
	"Bahrain - FA Cup Corners" : 198287,
},

"Chile" : 
{
	"Chile - Segunda Division" : 201664,
	"Chile - Super Cup Corners" : 218339,
	"Chile - Tercera Division A" : 201845,
	"Chile - Primera Division Women" : 220243,
	"Chile - Primera Division" : 1857,
	"Chile - Cup" : 1856,
	"Chile - Super Cup" : 197657,
	"Chile - Primera Division Corners" : 10658,
	"Chile - Primera B" : 10279,
	"Chile - Primera B Corners" : 72423,
	"Chile - Cup Corners" : 10587,
	"Chile - U21 League" : 223366,
},

"Cyprus" : 
{
	"Cyprus - 2nd Division" : 201240,
	"Cyprus - Cup Women" : 7955,
	"Cyprus - Cup Corners" : 198473,
	"Cyprus - 1st Division Women" : 210014,
	"Cyprus - 1st Division Corners" : 6648,
	"Cyprus - Cup" : 1888,
	"Cyprus - 1st Division" : 1887,
	"Cyprus - Super Cup" : 1890,
},

"Middle East" : 
{
	"UAFA - Arab Cup U20" : 208231,
	"UAFA - Arab Club Champions Cup" : 199525,
},

"Maldives" : 
{
	"Maldives - President Cup" : 225320,
	"Maldives - Premier League" : 218649,
},

"Kuwait" : 
{
	"Kuwait - Crown Prince Cup" : 200547,
	"Kuwait - Youth League U20" : 192335,
	"Kuwait - Super Cup" : 191669,
	"Kuwait - Youth League U21" : 222926,
	"Kuwait - Emir Cup" : 194698,
	"Kuwait - Division 1" : 212200,
	"Kuwait - Federation Cup" : 216391,
	"Kuwait - Premier League" : 10380,
	"Kuwait - Emir Cup Corners" : 198390,
	"Kuwait - Premier League Corners" : 198114,
},

"Ecuador" : 
{
	"Ecuador - Serie B" : 197248,
	"Ecuador - Serie A" : 5598,
	"Ecuador - Supercopa Corners" : 207920,
	"Ecuador - U19 League" : 223271,
	"Ecuador - Cup Corners" : 220664,
	"Ecuador - Supercopa" : 207919,
	"Ecuador - Serie A Corners" : 6668,
	"Ecuador - Reserve League" : 214816,
	"Ecuador - Cup" : 219609,
	"Ecuador - Primera Women" : 219344,
},

"Egypt" : 
{
	"Egypt - 2nd Division A" : 210213,
	"Egypt - League Cup" : 218174,
	"Egypt - Cup" : 1946,
	"Egypt - Premier League" : 9885,
	"Egypt - Super Cup Corners" : 198533,
	"Egypt - Cup Corners" : 198222,
	"Egypt - Premier League Women" : 217925,
	"Egypt - 2nd Division B" : 233451,
	"Egypt - Premier League Corners" : 125463,
	"Egypt - League Cup Corners" : 224954,
	"Egypt - Super Cup" : 198532,
},

"Undefined" : 
{
	"Poland - Super Cup Corners" : 205812,
	"UEFA - Nations League C Corners" : 200728,
	"UEFA - Nations League D Corners" : 200729,
	"CONMEBOL - Copa America Qualifiers Corners" : 192522,
	"International - Friendlies II Corners" : 10597,
	"Mexico - Champion of Champions Corners" : 205751,
	"FIFA - World Cup Women Corners" : 187537,
	"World - J.League Asia Challenge Corners" : 204015,
	"Canada - Championship Corners" : 199309,
	"FIFA - World Cup Qualifiers CONCACAF Corners" : 194728,
},

"Greece" : 
{
	"Greece - Super League Corners" : 6756,
	"Greece - Super League" : 2081,
	"Greece - Cup" : 2080,
	"Greece - Super League 2" : 206711,
	"Greece - Football League Corners" : 198084,
	"Greece - Gamma Ethniki" : 217489,
	"Greece - Cup Corners" : 218395,
	"Greece - Super League U19" : 192531,
	"Greece - Football League" : 10250,
},

"Serbia" : 
{
	"Serbia - Super Liga Women" : 221776,
	"Serbia - U19 League" : 209605,
	"Serbia - Prva Liga" : 206162,
	"Serbia - Super Liga" : 2434,
	"Serbia - Cup" : 2435,
	"Serbia - Cup Corners" : 202877,
},

"Ukraine" : 
{
	"Ukraine - Premier League" : 2650,
	"Ukraine - Cup Corners" : 6845,
	"Ukraine - U19 League" : 125456,
	"Ukraine - Cup" : 2647,
	"Ukraine - Youth Championship U21" : 9811,
	"Ukraine - Super Cup" : 215933,
	"Ukraine - Persha Liga" : 201145,
	"Ukraine - Premier League Women" : 210722,
	"Ukraine - Youth Championship U21 Corners" : 198000,
	"Ukraine - Druha Liga" : 212591,
	"Ukraine - Premier League  Corners" : 6809,
},

"Malta" : 
{
	"Malta - Super Cup" : 198220,
	"Malta - FA Trophy" : 2236,
	"Malta - Premier League - Corner" : 204781,
	"Malta - Premier League" : 2238,
	"Malta - Challenge League" : 210657,
},

"Taiwan" : 
{
	"Chinese Taipei - Mulan League Cup Women" : 222667,
	"Chinese Taipei - Premier League" : 201732,
	"Chinese Taipei - League Two" : 222564,
	"Chinese Taipei - Mulan Football League Women" : 208875,
},

"Dominica" : 
{
	"Dominica - Premier League" : 227303,
},

"Hong Kong" : 
{
	"Hong Kong - Sapling Cup Corners" : 198047,
	"Hong Kong - Reserve Division" : 200812,
	"Hong Kong - Senior Shield" : 191825,
	"Hong Kong - Premier League Women" : 217451,
	"Hong Kong - League Cup" : 10363,
	"Hong Kong - Senior Shield Corners" : 198229,
	"Hong Kong - Cup" : 199789,
	"Hong Kong - HKFA 2. Division" : 216761,
	"Hong Kong - Cup Corners" : 199791,
	"Hong Kong - FA Cup Corners" : 198209,
	"Hong Kong - FA Cup" : 10940,
	"Hong Kong - Sapling Cup" : 192446,
	"Hong Kong - Premier League Corners" : 230397,
	"Hong Kong - HKFA 1. Division" : 197637,
	"Hong Kong - FA Cup Junior Division" : 218009,
	"Hong Kong - Premier League" : 9809,
},

"Nicaragua" : 
{
	"Nicaragua - Primera Division" : 197584,
	"Nicaragua - Copa Nicaragua" : 214558,
	"Nicaragua - Liga Primera U20" : 208823,
},

"Latvia" : 
{
	"Latvia - 1st Liga" : 202003,
	"Latvia - Virsliga Corners" : 9542,
	"Latvia - Virsliga" : 2203,
	"Latvia - Cup" : 2204,
},

"San Marino" : 
{
	"San Marino - Super Cup" : 215618,
	"San Marino - Cup" : 210220,
	"San Marino - Campionato" : 210115,
},

"Congo DR" : 
{
	"Congo DR - Ligue 1" : 211034,
},

"Turkmenistan" : 
{
	"Turkmenistan - Higher League" : 208912,
},

"Gibraltar" : 
{
	"Gibraltar - Rock Cup" : 218535,
	"Gibraltar - Super Cup" : 200801,
	"Gibraltar - Football League" : 10748,
},

"Trinidad and Tobago" : 
{
	"Trinidad and Tobago - Super League" : 201930,
	"Trinidad and Tobago - TT Pro League" : 202243,
	"Trinidad and Tobago - TT Premier Football League 2" : 234496,
	"Trinidad and Tobago - Ascension Tournament" : 219361,
	"Trinidad and Tobago - League Cup" : 201873,
},

"Estonia" : 
{
	"Estonia - Esiliiga A" : 201775,
	"Estonia - Super Cup" : 224548,
	"Estonia - Esiliiga B" : 201776,
	"Estonia - Cup Women" : 219393,
	"Estonia - Winter Tournament" : 200541,
	"Estonia - Meistriliiga Women" : 205439,
	"Estonia - U19 League" : 205117,
	"Estonia - Cup" : 125461,
	"Estonia - Meistriliiga Corners" : 9544,
	"Estonia - II Liiga" : 209883,
	"Estonia - Meistriliiga" : 1989,
},

"Tunisia" : 
{
	"Tunisia - Cup" : 2572,
	"Tunisia - League 1 Corners" : 191934,
	"Tunisia - League 2" : 201236,
	"Tunisia - League 1" : 10355,
},

"Malawi" : 
{
	"Malawi - Super League" : 211386,
},

"Burundi" : 
{
	"Burundi - Premier League" : 208777,
},

"Montenegro" : 
{
	"Montenegro - Cup" : 219391,
	"Montenegro - Druga Liga" : 209191,
	"Montenegro - Prva Liga Corners" : 206166,
	"Montenegro - Prva Liga" : 206165,
},

"Sudan" : 
{
	"Sudan - Premier League" : 214757,
},

"Sri Lanka" : 
{
	"Sri Lanka - Super League" : 217765,
	"Sri Lanka - Presidents Cup" : 226656,
},

"Ivory Coast" : 
{
	"Ivory Coast - Ligue 1" : 217754,
},

"Saint Kitts and Nevis" : 
{
	"Saint Kitts and Nevis - Premier League" : 226865,
},

"Kiribati" : 
{
	"Kosovo - Superliga" : 211172,
},

"Aruba" : 
{
	"Aruba - Copa Betico" : 233910,
	"Aruba - Divison di Honor" : 208767,
},

"Cambodia" : 
{
	"Cambodia - League 2" : 230383,
	"Cambodia - Super Cup" : 227020,
	"Cambodia - Premier League" : 204591,
	"Cambodia - Cup" : 209661,
},

"Venezuela" : 
{
	"Venezuela - Primera Division" : 5596,
	"Venezuela - Primera Division Corners" : 198060,
	"Venezuela - Cup Corners" : 199717,
	"Venezuela - Segunda Division Corners" : 201259,
	"Venezuela - Cup" : 5597,
	"Venezuela - Segunda Division" : 201212,
},

"Macedonia" : 
{
	"North Macedonia - 2nd League" : 212550,
	"North Macedonia - Cup" : 207309,
	"North Macedonia - 1st League" : 2230,
},

"Laos" : 
{
	"Laos - League 1" : 225136,
},

"Haiti" : 
{
	"Haiti - Division 1" : 208754,
},

"Macao" : 
{
	"Macau - Primeira Divisao" : 201899,
	"Macau - FA Cup" : 220142,
},

"Uganda" : 
{
	"Uganda - Cup" : 212859,
	"Uganda - Division 2" : 217342,
	"Uganda - Premier League" : 211166,
},

"Uzbekistan" : 
{
	"Uzbekistan - Pro League" : 210207,
	"Uzbekistan - Cup Corners" : 201261,
	"Uzbekistan - Super League" : 202026,
	"Uzbekistan - Super League Corners" : 220547,
	"Uzbekistan - Super Cup" : 212333,
	"Uzbekistan - Womens League" : 215587,
	"Uzbekistan - Cup" : 131783,
},

"Morocco" : 
{
	"Morocco - Botola 2" : 207422,
	"Morocco - Division 1 Women" : 213220,
	"Morocco - Botola Pro" : 2253,
	"Morocco - Cup Corners" : 191936,
	"Morocco - Cup" : 10288,
	"Morocco - Botola Pro Corners" : 198045,
},

"Pakistan" : 
{
	"Pakistan - Premier League" : 215339,
	"Pakistan - Challenge Cup" : 211121,
},

"Andorra" : 
{
	"Andorra - Cup" : 233882,
	"Andorra - Premier Division" : 211232,
},

"Bhutan" : 
{
	"Bhutan - Coronation Championship" : 220084,
	"Bhutan - National Championship Women" : 216774,
	"Bhutan - President's Cup" : 218132,
	"Bhutan - Premier League" : 210712,
},

"Mauritania" : 
{
	"Mauritania - Ligue 2" : 234071,
	"Mauritania - Ligue 1" : 218013,
},

"Zambia" : 
{
	"Zambia - Super League" : 211601,
},

"Syria" : 
{
	"Syria - Premier League" : 10334,
},

"Honduras" : 
{
	"Honduras - Reserve League" : 222343,
	"Honduras - Liga de Ascenso" : 222335,
	"Honduras - Cup" : 202695,
	"Honduras - Liga Nacional" : 196865,
	"Hong Kong - HKFA 3. Division" : 216763,
},

"Mozambique" : 
{
	"Mozambique - Mocambola" : 216106,
},

"Guatemala" : 
{
	"Guatemala - Liga Nacional" : 2088,
	"Guatemala - Reserve League" : 222317,
	"Guatemala - Cup" : 202607,
	"Guatemala - Primera Division de Ascenso" : 202739,
	"Guatemala - Liga Nacional Corners" : 198043,
	"Guatemala - Segunda Division" : 236291,
},

"Barbados" : 
{
	"Barbados - Premier League" : 201863,
	"Barbados - Super Cup" : 206715,
},

"Gambia" : 
{
	"Gambia - GFA League" : 212509,
},

"Angola" : 
{
	"Angola - Girabola" : 208764,
},

"Liechtenstein" : 
{
	"Liechtenstein - Cup" : 219535,
},

"Philippines" : 
{
	"Philippines - PFL Cup" : 185648,
	"Philippines - Copa Paulino Alcantara" : 202605,
	"Philippines - PFL" : 10745,
	"Philippines - National Club Championship" : 10606,
},

"Benin" : 
{
	"Benin - Ligue 1" : 212495,
},

"Oceania" : 
{
	"Oceania - Olympic Qualifiers" : 227691,
	"FIFA - World Cup Qualifiers Oceania" : 5001,
	"OFC - Champions League" : 125458,
},

"Antigua and Barbuda" : 
{
	"Antigua and Barbuda - Premier Division" : 203106,
},

"Mongolia" : 
{
	"Mongolia - Cup" : 236724,
},

"Iraq" : 
{
	"Iraq - Premier League" : 125378,
},

"Palestine" : 
{
	"Palestine - West Bank League Corners" : 198068,
	"Palestine - West Bank League" : 10270,
	"Palestine - Cup" : 199307,
	"Palestine - West Bank Division 1" : 210655,
},

"Brunei Darussalam" : 
{
	"Brunei - Super League" : 203078,
},

"Mali" : 
{
	"Mali - Premiere Division" : 218137,
},

"El Salvador" : 
{
	"El Salvador - Copa El Salvador" : 203207,
	"El Salvador - Primera Division Women" : 219328,
	"El Salvador - Primera Division Corners" : 201317,
	"El Salvador - Reserve League U20" : 211044,
	"El Salvador - Primera Division" : 196742,
},

"Moldova" : 
{
	"Moldova - Cup" : 209278,
	"Moldova - Divizia Nationala" : 205096,
},

"Burkina Faso" : 
{
	"Burkina Faso - Premier League" : 211118,
},

"Dominican Republic" : 
{
	"Dominican Republic - Liga Mayor" : 215033,
},

"Libya" : 
{
	"Libya - Premier" : 2208,
},

"Solomon Islands" : 
{
	"Solomon Islands - S-League" : 214731,
},

"Swaziland" : 
{
	"Switzerland - 2. Liga Interregional" : 227469,
},

"Togo" : 
{
	"Togo - Championnat National" : 218786,
},
}


import base64
from unittest.mock import Mock, patch

import pytest
import requests

from PS3838.PS3838Retrieve import Retrieve
from PS3838.utils.constants import URL_PS3838


@pytest.fixture
def credentials():
    return {"username": "test_user", "password": "test_pass"}

@pytest.fixture
def retrieve_instance(credentials):
    return Retrieve(credentials=credentials)

def test_get_auth_header(retrieve_instance, credentials):
    expected_auth_str = f"{credentials['username']}:{credentials['password']}"
    expected_b64_auth_str = base64.b64encode(expected_auth_str.encode('utf-8')).decode('utf-8')
    expected_auth_header = {"Authorization": f"Basic {expected_b64_auth_str}"}

    assert retrieve_instance._auth_header == expected_auth_header

@patch('requests.get')
def test_make_request_get(mock_get, retrieve_instance):
    mock_response = Mock()
    expected_json = {"key": "value"}
    mock_response.json.return_value = expected_json
    mock_response.raise_for_status = Mock()
    mock_get.return_value = mock_response

    endpoint = "/test"
    params = {"param": "value"}
    response = retrieve_instance._make_request(endpoint, params=params)

    mock_get.assert_called_once_with(f"{URL_PS3838}{endpoint}", headers=retrieve_instance._auth_header, params=params)
    assert response == expected_json

@patch('requests.get')
def test_make_request_get_error(mock_get, retrieve_instance):
    mock_response = Mock()
    mock_response.raise_for_status.side_effect = requests.exceptions.HTTPError("HTTP error")
    mock_get.return_value = mock_response

    endpoint = "/test"
    params = {"param": "value"}
    response = retrieve_instance._make_request(endpoint, params=params)

    mock_get.assert_called_once_with(f"{URL_PS3838}{endpoint}", headers=retrieve_instance._auth_header, params=params)
    assert response == {}

@patch('PS3838.PS3838Retrieve.Retrieve._make_request')
def test_get_fixtures_v3(mock_make_request, retrieve_instance):
    expected_response = {"fixtures": []}
    mock_make_request.return_value = expected_response

    sport_id = 29
    league_ids = [123, 456]
    is_live = True
    since = 1609459200
    event_ids = [789, 101]
    response = retrieve_instance.get_fixtures_v3(sport_id, league_ids, is_live, since, event_ids)

    expected_params = {
        "sportId": sport_id,
        "leagueIds": "123,456",
        "isLive": 1,
        "since": since,
        "eventIds": "789,101"
    }

    mock_make_request.assert_called_once_with("/v3/fixtures", expected_params)
    assert response == expected_response

@patch('PS3838.PS3838Retrieve.Retrieve._make_request')
def test_get_straight_line_v2(mock_make_request, retrieve_instance):
    expected_response = {"line": []}
    mock_make_request.return_value = expected_response

    league_id = 123
    handicap = -1.5
    odds_format = "Decimal"
    sport_id = 29
    event_id = 98765
    period_number = 1
    bet_type = "MONEYLINE"
    team = "Team1"
    side = "OVER"
    response = retrieve_instance.get_straight_line_v2(league_id, handicap, odds_format, sport_id, event_id, period_number, bet_type, team, side)

    expected_params = {
        "leagueId": league_id,
        "handicap": handicap,
        "oddsFormat": odds_format,
        "sportId": sport_id,
        "eventId": event_id,
        "periodNumber": period_number,
        "betType": bet_type,
        "team": team,
        "side": side
    }

    mock_make_request.assert_called_once_with("/v2/line", expected_params)
    assert response == expected_response

@patch('PS3838.PS3838Retrieve.Retrieve._make_request')
def test_get_sports_v3(mock_make_request, retrieve_instance):
    expected_response = {"sports": []}
    mock_make_request.return_value = expected_response

    response = retrieve_instance.get_sports_v3()

    mock_make_request.assert_called_once_with("/v3/sports")
    assert response == expected_response

@patch('PS3838.PS3838Retrieve.Retrieve._make_request')
def test_get_leagues_v3(mock_make_request, retrieve_instance):
    expected_response = {"leagues": []}
    mock_make_request.return_value = expected_response

    sport_id = 29
    response = retrieve_instance.get_leagues_v3(sport_id)

    expected_params = {"sportId": sport_id}

    mock_make_request.assert_called_once_with("/v3/leagues", expected_params)
    assert response == expected_response





from datetime import datetime

import pytest

from PS3838.utils.errors import ParameterError
from PS3838.utils.tools_check import check_list_matches


def test_check_list_matches_success():
    list_matches = [
        {
            "league": "Premier League",
            "team1": "Team A",
            "team2": "Team B",
            "date": datetime(2024, 7, 15, 0, 0)
        },
        {
            "league": "La Liga",
            "team1": "Team C",
            "team2": "Team D",
            "date": datetime(2024, 7, 16, 0, 0)
        }
    ]
    try:
        check_list_matches(list_matches)
    except ParameterError:
        pytest.fail("check_list_matches raised ParameterError unexpectedly!")

def test_check_list_matches_missing():
    with pytest.raises(ParameterError, match="The list of matches is missing"):
        check_list_matches(None)

def test_check_list_matches_not_a_list():
    with pytest.raises(ParameterError, match="The list of matches must be a list"):
        check_list_matches("not_a_list")

def test_check_list_matches_invalid_match():
    list_matches = [
        {
            "league": "Premier League",
            "team1": "Team A",
            "team2": "Team B",
            "date": datetime(2024, 7, 15, 0, 0)
        },
        {
            "league": "La Liga",
            "team1": "Team C"
            # Missing team2 and date
        }
    ]
    with pytest.raises(ParameterError):
        check_list_matches(list_matches)




# Create a new error class called ParameterError that inherits from the built-in ValueError class.
from typing import Any, Dict, List, Optional


class CredentialError(Exception):
    def __init__(self, message: str = None, *args: Any):
        if message :
            self.message = message
            super().__init__(self.message, *args)

class ParameterError(Exception):
    def __init__(self, message: str = None, *args: Any):
        if message :
            self.message = message
            super().__init__(self.message, *args)

class RetrieveMatchError(Exception):
    def __init__(self, message: str = None, *args: Any):
        if message :
            self.message = message
            super().__init__(self.message, *args)

class RetrieveOddsError(Exception):
    def __init__(self, message: str = None, *args: Any):
        if message :
            self.message = message
            super().__init__(self.message, *args)



import pytest

from PS3838.utils.errors import RetrieveMatchError
from PS3838.utils.tools_code import find_league_id

LEAGUES = {
        "leagues": [
            {'id': 199618, 'name': 'Italy - Super Cup Bookings', 'homeTeamType': 'Team1', 'hasOfferings': False, 'container': 'Italy', 'allowRoundRobins': True, 'leagueSpecialsCount': 0, 'eventSpecialsCount': 0, 'eventCount': 0}, {'id': 1979, 'name': 'England - FA Cup', 'homeTeamType': 'Team1', 'hasOfferings': False, 'container': 'England', 'allowRoundRobins': True, 'leagueSpecialsCount': 0, 'eventSpecialsCount': 0, 'eventCount': 0}, {'id': 1989, 'name': 'Estonia - Meistriliiga', 'homeTeamType': 'Team1', 'hasOfferings': True, 'container': 'Estonia', 'allowRoundRobins': True, 'leagueSpecialsCount': 0, 'eventSpecialsCount': 20, 'eventCount': 3}, {'id': 196861, 'name': 'Norway - Toppserien Women', 'homeTeamType': 'Team1', 'hasOfferings': False, 'container': 'Norway', 'allowRoundRobins': True, 'leagueSpecialsCount': 0, 'eventSpecialsCount': 0, 'eventCount': 0}, {'id': 218098, 'name': 'Israel - Liga Leumit U19', 'homeTeamType': 'Team1', 'hasOfferings': False, 'container': 'Israel', 'allowRoundRobins': False, 'leagueSpecialsCount': 0, 'eventSpecialsCount': 0, 'eventCount': 0}
        ]
    }

def test_find_league_id_by_id():
    assert find_league_id(LEAGUES, 1989) == 1989

def test_find_league_id_by_name():
    assert find_league_id(LEAGUES, "England - FA Cup") == 1979

def test_find_league_id_case_insensitive():
    assert find_league_id(LEAGUES, "england fa cup") == 1979

def test_find_league_id_with_spaces():
    assert find_league_id(LEAGUES, " england -fa cup  ") == 1979

def test_find_league_id_with_punctuation():
    assert find_league_id(LEAGUES, " england! -fa @cup  ") == 1979

def test_find_league_id_not_found():
    with pytest.raises(RetrieveMatchError):
        find_league_id(LEAGUES, "Bundesliga")

def test_find_league_id_invalid_type():
    with pytest.raises(RetrieveMatchError):
        find_league_id(LEAGUES, ["La Liga"])


from datetime import datetime

import pytest

from PS3838.utils.errors import ParameterError
from PS3838.utils.tools_check import check_match


def test_check_match_success():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "date": datetime(2024, 7, 15, 0, 0)
    }
    try:
        check_match(match)
    except ParameterError:
        pytest.fail("check_match raised ParameterError unexpectedly!")

def test_check_match_success_to_bet():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "date": datetime(2024, 7, 15, 0, 0),
        "result": 1,
        "amount": 10,
        "odd_min": 1.5
    }
    try:
        check_match(match, to_bet=True)
    except ParameterError:
        pytest.fail("check_match raised ParameterError unexpectedly!")

def test_check_match_not_a_dict():
    with pytest.raises(ParameterError, match="Each match must be a dictionary"):
        check_match("not_a_dict")

def test_check_match_missing_league():
    match = {
        "team1": "Team A",
        "team2": "Team B"
    }
    with pytest.raises(ParameterError):
        check_match(match)

def test_check_match_missing_team1():
    match = {
        "league": "Premier League",
        "team2": "Team B"
    }
    with pytest.raises(ParameterError):
        check_match(match)

def test_check_match_missing_team2():
    match = {
        "league": "Premier League",
        "team1": "Team A"
    }
    with pytest.raises(ParameterError):
        check_match(match)

def test_check_match_league_not_str_or_int():
    match = {
        "league": ["Premier League"],
        "team1": "Team A",
        "team2": "Team B"
    }
    with pytest.raises(ParameterError):
        check_match(match)

def test_check_match_team1_not_str():
    match = {
        "league": "Premier League",
        "team1": 123,
        "team2": "Team B"
    }
    with pytest.raises(ParameterError):
        check_match(match)

def test_check_match_team2_not_str():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": 123
    }
    with pytest.raises(ParameterError):
        check_match(match)

def test_check_match_date_not_datetime():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "date": "2024-07-15"
    }
    with pytest.raises(ParameterError):
        check_match(match)

def test_check_match_missing_result_to_bet():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "amount": 10,
        "odd_min": 1.5
    }
    with pytest.raises(ParameterError):
        check_match(match, to_bet=True)

def test_check_match_missing_amount_to_bet():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "result": 1,
        "odd_min": 1.5
    }
    with pytest.raises(ParameterError):
        check_match(match, to_bet=True)

def test_check_match_missing_odd_min_to_bet():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "result": 1,
        "amount": 10
    }
    with pytest.raises(ParameterError):
        check_match(match, to_bet=True)

def test_check_match_result_not_int():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "result": "one",
        "amount": 10,
        "odd_min": 1.5
    }
    with pytest.raises(ParameterError):
        check_match(match, to_bet=True)

def test_check_match_amount_not_int():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "result": 1,
        "amount": "ten",
        "odd_min": 1.5
    }
    with pytest.raises(ParameterError):
        check_match(match, to_bet=True)

def test_check_match_odd_min_not_float():
    match = {
        "league": "Premier League",
        "team1": "Team A",
        "team2": "Team B",
        "result": 1,
        "amount": 10,
        "odd_min": 1
    }
    with pytest.raises(ParameterError):
        check_match(match, to_bet=True)




from PS3838.utils.tools_code import normalize_name


def test_normalize_name_all_lowercase():
    assert normalize_name("example") == "example"

def test_normalize_name_all_uppercase():
    assert normalize_name("EXAMPLE") == "example"

def test_normalize_name_mixed_case():
    assert normalize_name("ExAmPlE") == "example"

def test_normalize_name_with_spaces_in_the_middle():
    assert normalize_name("example name") == "examplename"

def test_normalize_name_with_spaces_at_the_end():
    assert normalize_name("example ") == "example"

def test_normalize_name_with_spaces_at_the_beginning():
    assert normalize_name(" example") == "example"

def test_normalize_name_with_punctuation():
    assert normalize_name("example.name!") == "examplename"

def test_normalize_name_with_numbers():
    assert normalize_name("example123") == "example123"

def test_normalize_name_mixed_characters():
    assert normalize_name("Exa mple123!") == "example123"

def test_normalize_name_empty_string():
    assert normalize_name("") == ""

def test_normalize_name_only_special_characters():
    assert normalize_name("!!!") == ""

def test_normalize_name_with_underscore():
    assert normalize_name("example_name") == "examplename"

def test_normalize_name_with_hyphen():
    assert normalize_name("example-name") == "examplename"

def test_normalize_name_with_unicode_characters():
    assert normalize_name("exámplè") == "exámplè"
    





from PS3838.utils.tools_code import change_date


def test_change_date_add_days():
    date = "2024-07-15T00:00:00Z"
    expected_date = "2024-07-17T00:00:00Z"
    assert change_date(date, 2, 0) == expected_date

def test_change_date_add_hours():
    date = "2024-07-15T00:00:00Z"
    expected_date = "2024-07-15T05:00:00Z"
    assert change_date(date, 0, 5) == expected_date

def test_change_date_add_days_and_hours():
    date = "2024-07-15T00:00:00Z"
    expected_date = "2024-07-17T05:00:00Z"
    assert change_date(date, 2, 5) == expected_date

def test_change_date_subtract_days():
    date = "2024-07-15T00:00:00Z"
    expected_date = "2024-07-13T00:00:00Z"
    assert change_date(date, -2, 0) == expected_date

def test_change_date_subtract_hours():
    date = "2024-07-15T05:00:00Z"
    expected_date = "2024-07-15T00:00:00Z"
    assert change_date(date, 0, -5) == expected_date

def test_change_date_subtract_days_and_hours():
    date = "2024-07-15T05:00:00Z"
    expected_date = "2024-07-13T00:00:00Z"
    assert change_date(date, -2, -5) == expected_date

def test_change_date_add_days_over_month():
    date = "2024-07-28T00:00:00Z"
    expected_date = "2024-08-02T00:00:00Z"
    assert change_date(date, 5, 0) == expected_date

def test_change_date_add_hours_over_day():
    date = "2024-07-15T23:00:00Z"
    expected_date = "2024-07-16T01:00:00Z"
    assert change_date(date, 0, 2) == expected_date



from datetime import datetime
from unittest.mock import Mock, patch

from PS3838.PS3838 import retrieving
from PS3838.PS3838Retrieve import Retrieve

LEAGUE_RESPONSE = {
    "leagues": [
        {"id": 1872, "name": "CONMEBOL - Copa America"},
        {"id": 1873, "name": "La Liga"}
    ]
}

FIXTURES_RESPONSE = {
    "league": [
        {
            "events": [
                {'id': 1593707406, 'starts': '2024-07-15T00:00:00Z', 'home': 'Argentina', 'away': 'Colombia', 'rotNum': '30805', 'liveStatus': 2, 'status': 'O', 'parlayRestriction': 2, 'altTeaser': False, 'resultingUnit': 'Regular', 'betAcceptanceType': 0, 'version': 538876225},
                {'id': 1593707403, 'starts': '2024-07-14T00:00:00Z', 'home': 'Canada', 'away': 'Uruguay', 'rotNum': '30801', 'liveStatus': 2, 'status': 'O', 'parlayRestriction': 2, 'altTeaser': False, 'resultingUnit': 'Regular', 'betAcceptanceType': 0, 'version': 538881047}
            ]
        }
    ]
}

def test_retrieving_success():
    mock_api_retrieve = Mock(spec=Retrieve)
    mock_api_retrieve.get_leagues_v3.return_value = LEAGUE_RESPONSE
    mock_api_retrieve.get_fixtures_v3.return_value = FIXTURES_RESPONSE
    mock_api_retrieve.get_straight_line_v2.side_effect = [
        {"price": 1.5, "line_id": 1},
        {"price": 2.5, "line_id": 1},
        {"price": 3.5, "line_id": 1}
    ]

    credentials = {"username": "test", "password": "test"}
    list_matches = [
        {
            'id': 1,
            'league': 'CONMEBOL - Copa America',
            'team1': 'Colom',
            'team2': 'Argentina',
            'date': datetime(2024, 7, 15, 0, 0),
            'result': 2,
            'amount': 5,
            'odd_min': 1.05
        }
    ]

    match_odds = retrieving(credentials, list_matches, mock_api_retrieve)

    assert len(match_odds) == 1
    assert match_odds[0][0]["id"] == 1593707406
    assert match_odds[0][1]["team1_odds"] == 1.5
    assert match_odds[0][1]["team2_odds"] == 2.5
    assert match_odds[0][1]["draw_odds"] == 3.5

@patch('PS3838.PS3838.Retrieve', autospec=True)
@patch('PS3838.PS3838.check_credentials')
@patch('PS3838.PS3838.check_list_matches')
@patch('PS3838.PS3838.retrieve_matches')
@patch('PS3838.PS3838.get_team_odds')
def test_retrieving_without_api_retrieve(mock_get_team_odds, mock_retrieve_matches, mock_check_list_matches, mock_check_credentials, mock_retrieve):
    mock_api_retrieve_instance = Mock(spec=Retrieve)
    mock_retrieve.return_value = mock_api_retrieve_instance
    mock_retrieve_matches.return_value = [
        {'id': 1593707406, 'league': 1872, 'result': 2, 'amount': 5, 'odd_min': 1.05, 'home': 'Argentina', 'away': 'Colombia', 'starts': '2024-07-15T00:00:00Z'}
    ]
    mock_get_team_odds.side_effect = [
        (1.5, 1),  # Team1 odds
        (2.5, 1),  # Draw odds
        (3.5, 1)   # Team2 odds
    ]

    credentials = {"username": "test", "password": "test"}
    list_matches = [
        {
            'id': 1,
            'league': 'CONMEBOL - Copa America',
            'team1': 'Colom',
            'team2': 'Argentina',
            'date': datetime(2024, 7, 15, 0, 0),
            'result': 2,
            'amount': 5,
            'odd_min': 1.05
        }
    ]

    match_odds = retrieving(credentials, list_matches)

    assert len(match_odds) == 1
    assert match_odds[0][0]["id"] == 1593707406
    assert match_odds[0][1]["team1_odds"] == 1.5
    assert match_odds[0][1]["draw_odds"] == 3.5
    assert match_odds[0][1]["team2_odds"] == 2.5
    mock_retrieve.assert_called_once_with(credentials=credentials)


def test_retrieving_partial_success():
    mock_api_retrieve = Mock(spec=Retrieve)
    mock_api_retrieve.get_leagues_v3.return_value = LEAGUE_RESPONSE
    mock_api_retrieve.get_fixtures_v3.return_value = FIXTURES_RESPONSE
    mock_api_retrieve.get_straight_line_v2.side_effect = [
        {"price": 1.5, "line_id": 1},
        {"price": 2.5, "line_id": 1},
        {"price": 3.5, "line_id": 1},
        {"price": 1.8, "line_id": 2},
        {"price": 2.8, "line_id": 2},
        {"price": 3.8, "line_id": 2}
    ]

    credentials = {"username": "test", "password": "test"}
    list_matches = [
        {
            'id': 1,
            'league': 'CONMEBOL - Copa America',
            'team1': 'Colom',
            'team2': 'Argentina',
            'date': datetime(2024, 7, 15, 0, 0),
            'result': 2,
            'amount': 5,
            'odd_min': 1.05
        },
        {
            'id': 2,
            'league': 'CONMEBOL - Copa America',
            'team1': 'Canada',
            'team2': 'Uruguay',
            'date': datetime(2024, 7, 14, 0, 0),
            'result': 1,
            'amount': 10,
            'odd_min': 1.10
        }
    ]

    match_odds = retrieving(credentials, list_matches, mock_api_retrieve)

    assert len(match_odds) == 2
    assert match_odds[0][0]["id"] == 1593707406
    assert match_odds[0][1]["team1_odds"] == 1.5
    assert match_odds[0][1]["team2_odds"] == 2.5
    assert match_odds[0][1]["draw_odds"] == 3.5
    
    assert match_odds[1][0]["id"] == 1593707403
    assert match_odds[1][1]["team1_odds"] == 1.8
    assert match_odds[1][1]["team2_odds"] == 2.8
    assert match_odds[1][1]["draw_odds"] == 3.8
    

def test_retrieving_empty_list():
    mock_api_retrieve = Mock(spec=Retrieve)

    credentials = {"username": "test", "password": "test"}
    list_matches = []

    match_odds = retrieving(credentials, list_matches, mock_api_retrieve)

    assert match_odds == []


from datetime import datetime
from typing import Any, Dict, List

from PS3838.utils.errors import CredentialError, ParameterError


def check_credentials(credentials : Dict[str, str] = None) -> None:
    if not credentials:
        raise CredentialError("Credentials are missing")
    if not isinstance(credentials, dict):
        raise CredentialError("Credentials must be a dictionary")
    if not all(key in credentials for key in ["username", "password"]):
        raise CredentialError("Credentials must contain 'username' and 'password' keys")
    if not all(isinstance(credentials[key], str) for key in ["username", "password"]):
        raise CredentialError("Credentials 'username' and 'password' must be strings")



def check_list_matches(list_matches : List[Dict[str, Any]] = None, to_bet : bool = False) -> None:
    # check if the list of matches is provided
    if not list_matches:
        raise ParameterError("The list of matches is missing")
    
    # check if the list of matches is a list
    if not isinstance(list_matches, list):
        raise ParameterError("The list of matches must be a list")
    
    # check if to_bet is a boolean
    if type(to_bet) != bool:
        raise ParameterError("Parameter to_bet must be a boolean")
    
    # check each match in the list of matches
    for match in list_matches:
        check_match(match, to_bet=to_bet)


def check_match(match : Dict[str, Any], to_bet : bool = False) -> None:
    if not isinstance(match, dict):
        raise ParameterError("Each match must be a dictionary")
    if "league" not in match.keys():
        raise ParameterError(f"Parameter \"league\" is missing for at least one match")
    if "team1" not in match.keys():
        raise ParameterError(f"Parameter \"team1\" is missing for at least one match")
    if "team2" not in match.keys():
        raise ParameterError(f"Parameter \"team2\" is missing for at least one match")
    if type(match["league"]) not in [str, int]:
        raise ParameterError(f"\"league\" for match  {match['team1']} - {match['team2']}  must be a string or an integer")
    if type(match["team1"]) != str:
        raise ParameterError(f"\"team1\" for match  {match['team1']} - {match['team2']}  must be a string")
    if type(match["team2"]) != str:
        raise ParameterError(f"\"team2\" for match  {match['team1']} - {match['team2']}  must be a string")
    if "date" in match.keys() and type(match["date"]) != datetime:
        raise ParameterError(f"Date for match  {match['team1']} - {match['team2']}  must be a datetime object")
    if to_bet:
        if "result" not in match.keys():
            raise ParameterError(f"Result for match  {match['team1']} - {match['team2']}  is missing")
        if "amount" not in match.keys():
            raise ParameterError(f"Amount for match  {match['team1']} - {match['team2']}  is missing")
        if "odd_min" not in match.keys():
            raise ParameterError(f"Minimum odd for match  {match['team1']} - {match['team2']}  is missing")
        if type(match["result"]) != int or (type(match["result"]) == int and match["result"] not in [0, 1, 2]):
            raise ParameterError(f"Result for match  {match['team1']} - {match['team2']}  must be an integer in [0, 1, 2]")
        if (type(match["amount"]) != float and type(match["amount"]) != int) or (((type(match["amount"]) == int) or (type(match["amount"]) == float)) and match["amount"] < 5):
            raise ParameterError(f"Amount for match  {match['team1']} - {match['team2']}  must be an integer or a float greater than 5")
        if type(match["odd_min"]) != float or (type(match["odd_min"]) == float and match["odd_min"] < 1):
            raise ParameterError(f"Minimum odd for match {match['team1']} - {match['team2']}  must be a float greater than 1")
        



from setuptools import find_packages, setup

# Read the contents of your README file
with open('README.md') as f:
    LONG_DESCRIPTION = f.read()

DESCRIPTION = "A package to interact with the PS3838 API, especially to retrieve odds and bet automatically."

setup(
    name='PS3838',
    version='0.1.1',
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown', 
    author='Gaëtan Le Fournis',
    author_email='gaetanlf22@gmail.com',
    url='https://github.com/gaetanlefournis/PS3838.git',
    license='MIT',
    keywords='PS3838, bet, betting, odds, football, soccer',
    packages=find_packages(),
    classifiers=[
        # Development Status
        'Development Status :: 4 - Beta', # Still in development

        # License
        'License :: OSI Approved :: MIT License',

        # Programming Language
        'Programming Language :: Python', 
        'Programming Language :: Python :: 3',  
        'Programming Language :: Python :: 3.7',  
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        
        # Natural Language
        'Natural Language :: English', 
    ],
    install_requires=[
        'anyio>=4.4.0',
        'httpx>=0.27.0',
        'Levenshtein>=0.25.1',
        'python-dotenv>=1.0.1',
        'PyYAML>=6.0.1',
        'requests>=2.32.3',
        'rapidfuzz>=3.9.4',
    ],
    extras_require={
        'dev': [
            'pytest>=8.2.2',
            'pytest-cov>=5.0.0',
        ],
    },

    # A URL to a website containing documentation for your package.
    project_urls={
        'Bug Reports': 'https://github.com/gaetanlefournis/PS3838/issues',
        'Source': 'https://github.com/gaetanlefournis/PS3838',
    },
)
